@@ -10,4 +10,4 @@ See the :doc:`Method Card </method_cards/label_smoothing>` for more details.
 from composer.algorithms.label_smoothing.label_smoothing import LabelSmoothing as LabelSmoothing
 from composer.algorithms.label_smoothing.label_smoothing import smooth_labels as smooth_labels
 
-__all__ = ["LabelSmoothing", "smooth_labels"]
+__all__ = ['LabelSmoothing', 'smooth_labels']
