@@ -4,4 +4,4 @@
 """Helper utilities for algorithms."""
 from composer.algorithms.utils.augmentation_primitives import augmentation_sets
 
-__all__ = ["augmentation_sets"]
+__all__ = ['augmentation_sets']
