@@ -3,6 +3,7 @@
 
 """Log memory usage during training."""
 import logging
+import warnings
 from typing import Dict, Union
 
 import torch.cuda
@@ -13,19 +14,19 @@ from composer.loggers import Logger
 
 log = logging.getLogger(__name__)
 
-__all__ = ["MemoryMonitor"]
+__all__ = ['MemoryMonitor']
 
 
 class MemoryMonitor(Callback):
     """Logs the memory usage of the model.
 
-    This callback calls the torch memory stats API for cuda (see :func:`torch.cuda.memory_stats`) on the
-    :attr:`~composer.core.event.Event.AFTER_TRAIN_BATCH` and reports different memory statistics.
-
-    Example
+    This callback calls the torch memory stats API for CUDA (see :func:`torch.cuda.memory_stats`)
+    on the :attr:`.Event.AFTER_TRAIN_BATCH` and reports different memory statistics.
 
+    Example:
     .. doctest::
 
+        >>> from composer import Trainer
         >>> from composer.callbacks import MemoryMonitor
         >>> # constructing trainer object with this callback
         >>> trainer = Trainer(
@@ -37,10 +38,6 @@ class MemoryMonitor(Callback):
         ...     callbacks=[MemoryMonitor()],
         ... )
 
-    .. testcleanup::
-
-        trainer.engine.close()
-
     The memory statistics are logged by the :class:`~composer.loggers.logger.Logger` to the following keys as
     described below.
 
@@ -49,7 +46,7 @@ class MemoryMonitor(Callback):
     +==========================+=============================================================+
     |                          | Several memory usage statistics                             |
     | ``memory/{statistic}``   | are logged on                                               |
-    |                          | :attr:`~composer.core.event.Event.AFTER_TRAIN_BATCH` event. |
+    |                          | :attr:`.Event.AFTER_TRAIN_BATCH` event.                     |
     +--------------------------+-------------------------------------------------------------+
 
     The following statistics are recorded:
@@ -73,50 +70,47 @@ class MemoryMonitor(Callback):
     +----------------+--------------------------------------------------------------------------------+
 
     .. note::
-        Memory usage monitoring is only supported for the GPU devices.
+        Memory usage monitoring is only supported for GPU devices.
     """
 
-    def __init__(self):
-        super().__init__()
-        log.info(
-            "Memory monitor just profiles the current GPU assuming that the memory footprint across GPUs is balanced.")
-        if torch.cuda.device_count() == 0:
-            log.warning("Memory monitor only works on GPU devices.")
+    def __init__(self) -> None:
+        # Memory monitor takes no args
+        pass
+
+    def fit_start(self, state: State, logger: Logger) -> None:
+        # TODO(ravi) move this check would be on Event.INIT after #1084 is merged
+        # Not relying on `torch.cuda.is_available()` since the model could be on CPU.
+        model_device = next(state.model.parameters()).device
+
+        if model_device.type != 'cuda':
+            warnings.warn(f'The memory monitor only works on CUDA devices, but the model is on {model_device.type}.')
 
     def after_train_batch(self, state: State, logger: Logger):
         memory_report = {}
 
-        n_devices = torch.cuda.device_count()
-        if n_devices == 0:
+        model_device = next(state.model.parameters()).device
+        if model_device.type != 'cuda':
             return
 
         memory_report = _get_memory_report()
 
-        for mem_stat, val in memory_report.items():
-            logger.data_batch({'memory/{}'.format(mem_stat): val})
+        logger.data_batch({f'memory/{mem_stat}': val for (mem_stat, val) in memory_report.items()})
 
 
 _MEMORY_STATS = {
-    "allocation.all.allocated": "alloc_requests",
-    "allocation.all.freed": "free_requests",
-    "allocated_bytes.all.allocated": "allocated_mem",
-    "active_bytes.all.current": "active_mem",
-    "inactive_split_bytes.all.current": "inactive_mem",
-    "reserved_bytes.all.current": "reserved_mem",
-    "num_alloc_retries": "alloc_retries",
+    'allocation.all.allocated': 'alloc_requests',
+    'allocation.all.freed': 'free_requests',
+    'allocated_bytes.all.allocated': 'allocated_mem',
+    'active_bytes.all.current': 'active_mem',
+    'inactive_split_bytes.all.current': 'inactive_mem',
+    'reserved_bytes.all.current': 'reserved_mem',
+    'num_alloc_retries': 'alloc_retries',
 }
 
 
 def _get_memory_report() -> Dict[str, Union[int, float]]:
-    if not torch.cuda.is_available():
-        log.debug("Cuda is not available. The memory report will be empty.")
-        return {}
     memory_stats = torch.cuda.memory_stats()
 
-    if len(memory_stats) == 0:
-        log.debug("No GPU memory was used, returning empty.")
-        return {}
-
     # simplify the memory_stats
     memory_report = {
         name: memory_stats[torch_name] for (torch_name, name) in _MEMORY_STATS.items() if torch_name in memory_stats
