@@ -13,11 +13,9 @@ from composer.loggers import Logger
 
 
 class ThresholdStopper(Callback):
-    """This callback tracks a training or evaluation metric and halts training when the 
-    metric value reaches a certain threshold.
-
-    Example
+    """Halt training when a metric value reaches a certain threshold.
 
+    Example:
     .. doctest::
 
         >>> from composer.callbacks.threshold_stopper import ThresholdStopper
@@ -40,10 +38,10 @@ class ThresholdStopper(Callback):
 
     Args:
         monitor (str): The name of the metric to monitor.
-        dataloader_label (str): The label of the dataloader or evaluator associated with the tracked metric. If 
-            monitor is in an Evaluator, the dataloader_label field should be set to the Evaluator's label. If 
+        dataloader_label (str): The label of the dataloader or evaluator associated with the tracked metric. If
+            monitor is in an Evaluator, the dataloader_label field should be set to the Evaluator's label. If
             monitor is a training metric or an ordinary evaluation metric not in an Evaluator, dataloader_label
-            should be set to 'train' or 'eval' respectively. If dataloader_label is set to 'train', then the 
+            should be set to 'train' or 'eval' respectively. If dataloader_label is set to 'train', then the
             callback will stop training in the middle of the epoch.
         threshold (float): The threshold that dictates when to halt training. Whether training stops if the metric
             exceeds or falls below the threshold depends on the comparison operator.
@@ -73,16 +71,16 @@ class ThresholdStopper(Callback):
         if callable(comp):
             self.comp_func = comp
         if isinstance(comp, str):
-            if comp.lower() in ("greater", "gt"):
+            if comp.lower() in ('greater', 'gt'):
                 self.comp_func = torch.greater
-            elif comp.lower() in ("less", "lt"):
+            elif comp.lower() in ('less', 'lt'):
                 self.comp_func = torch.less
             else:
                 raise ValueError(
                     "Unrecognized comp string. Use the strings 'gt', 'greater', 'lt' or 'less' or a callable comparison operator"
                 )
         if comp is None:
-            if any(substr in monitor.lower() for substr in ["loss", "error", "perplexity"]):
+            if any(substr in monitor.lower() for substr in ['loss', 'error', 'perplexity']):
                 self.comp_func = torch.less
             else:
                 self.comp_func = torch.greater
