@@ -15,7 +15,7 @@ from composer.core.event import Event
 from composer.core.state import State
 from composer.core.time import Time, TimeUnit
 
-__all__ = ["Evaluator", "evaluate_periodically", "ensure_evaluator"]
+__all__ = ['Evaluator', 'evaluate_periodically', 'ensure_evaluator']
 
 
 def evaluate_periodically(eval_interval: Union[str, Time, int], eval_at_fit_end: bool = True):
@@ -27,7 +27,8 @@ def evaluate_periodically(eval_interval: Union[str, Time, int], eval_at_fit_end:
         eval_at_fit_end (bool): Whether to evaluate at the end of training, regardless of `eval_interval`.
             Default: True
     Returns:
-        (State, Event) -> bool: A callable for the ``eval_interval`` argument of an :class:`.Evaluator`.
+        (State, Event) -> bool: A callable for the ``eval_interval`` argument of an
+            :class:`.Evaluator`.
     """
     if isinstance(eval_interval, int):
         eval_interval = Time(eval_interval, TimeUnit.EPOCH)
@@ -35,7 +36,7 @@ def evaluate_periodically(eval_interval: Union[str, Time, int], eval_at_fit_end:
         eval_interval = Time.from_timestring(eval_interval)
 
     if eval_interval.unit not in (TimeUnit.EPOCH, TimeUnit.BATCH):
-        raise ValueError("The `eval_interval` must have units of EPOCH or BATCH, or be a function.")
+        raise ValueError('The `eval_interval` must have units of EPOCH or BATCH, or be a function.')
 
     last_batch_seen = -1
 
@@ -66,12 +67,16 @@ def evaluate_periodically(eval_interval: Union[str, Time, int], eval_at_fit_end:
 class Evaluator:
     """A wrapper for a dataloader to include metrics that apply to a specific dataset.
 
-    For example, :class:`~.nlp_metrics.CrossEntropyLoss` metric for NLP models.
+    For example, :class:`.CrossEntropyLoss` metric for NLP models.
 
     .. doctest::
 
        >>> from torchmetrics.classification.accuracy import Accuracy
-       >>> eval_evaluator = Evaluator(label="myEvaluator", dataloader=eval_dataloader, metrics=Accuracy())
+       >>> eval_evaluator = Evaluator(
+       ...     label="myEvaluator",
+       ...     dataloader=eval_dataloader,
+       ...     metrics=Accuracy()
+       ... )
        >>> trainer = Trainer(
        ...     model=model,
        ...     train_dataloader=train_dataloader,
@@ -80,26 +85,18 @@ class Evaluator:
        ...     max_duration="1ep",
        ... )
 
-    .. testcleanup::
-
-        trainer.engine.close()
-
-
     Args:
-        label (str): Name of the Evaluator
-        dataloader (DataSpec | Iterable | Dict[str, Any]): Iterable that yields batches, a :class:`.DataSpec` for evaluation,
-            or a Dict of :class:`.DataSpec` kwargs.
-        metrics (Metric | MetricCollection): :class:`torchmetrics.Metric` to log. ``metrics`` will be deep-copied to
-            ensure that each evaluator updates only its ``metrics``.
-        subset_num_batches (int, optional): The maximum number of batches to use for each evaluation. Defaults to
-            ``None``, which means that the ``eval_subset_num_batches`` parameter from the
-            :class:`~composer.trainer.trainer.Trainer` will be used.
-
+        label (str): Name of the Evaluator.
+        dataloader (DataSpec | Iterable | Dict[str, Any]): Iterable that yields batches, a :class:`.DataSpec`
+            for evaluation, or a Dict of :class:`.DataSpec` kwargs.
+        metrics (torchmetrics.Metric | torchmetrics.MetricCollection): :class:`torchmetrics.Metric` to log.
+            ``metrics`` will be deep-copied to ensure that each evaluator updates only its ``metrics``.
+        subset_num_batches (int, optional): The maximum number of batches to use for each evaluation. Defaults to ``None``,
+            which means that the ``eval_subset_num_batches`` parameter from the :class:`.Trainer` will be used.
             Set to ``-1`` to evaluate the entire ``dataloader``
-        eval_interval (int | str | Time | (State, Event) -> bool, optional): An integer, which will be
-            interpreted to be epochs, a str (e.g. ``1ep``, or ``10ba``), a :class:`.Time` object, or a callable.
-            Defaults to ``None``, which means that the ``eval_interval`` parameter from the
-            :class:`~composer.trainer.trainer.Trainer` will be used.
+        eval_interval (Time | int | str | (State, Event) -> bool, optional): An integer,
+            which will be interpreted to be epochs, a str (e.g. ``1ep``, or ``10ba``), a :class:`.Time` object, or a callable.
+            Defaults to ``None``, which means that the ``eval_interval`` parameter from the :class:`.Trainer` will be used.
 
             If an integer (in epochs), :class:`.Time` string, or :class:`.Time` instance, the evaluator will be run
             with this frequency. :class:`.Time` strings or :class:`.Time` instances must have units of
@@ -115,8 +112,6 @@ class Evaluator:
             evenly divide the training duration.
     """
 
-    _eval_interval: Optional[Callable[[State, Event], bool]]
-
     def __init__(
         self,
         *,
@@ -137,6 +132,7 @@ class Evaluator:
             self.metrics = metrics
 
         self.subset_num_batches = subset_num_batches
+        self._eval_interval = None
         self.eval_interval = eval_interval
 
     @property
@@ -160,7 +156,8 @@ def ensure_evaluator(evaluator: Union[Evaluator, DataSpec, Iterable, Dict[str, A
     Args:
         evaluator (Evaluator | DataSpec | Iterable | Dict[str, Any]): A dataloader,
             :class:`.DataSpec` instance, dictionary of :class:`.DataSpec` kwargs, or existing evaluator.
-        default_metrics (Union[Metric, MetricCollection]): The metrics for the ``evaluator``, if a datalaoder was specified.
+        default_metrics (torchmetrics.Metric | torchmetrics.MetricCollection): The metrics for the ``evaluator``,
+            if a datalaoder was specified.
 
     Returns:
         Evaluator: An evaluator.
@@ -169,7 +166,7 @@ def ensure_evaluator(evaluator: Union[Evaluator, DataSpec, Iterable, Dict[str, A
         return evaluator
     else:
         return Evaluator(
-            label="eval",
+            label='eval',
             dataloader=evaluator,
             metrics=default_metrics,
         )
