@@ -24,7 +24,7 @@ from typing import Any, Dict, Generic, Optional, TypeVar, Union, cast
 from composer.core.serializable import Serializable
 from composer.utils.string_enum import StringEnum
 
-__all__ = ["TimeUnit", "Time", "Timestamp", "ensure_time"]
+__all__ = ['TimeUnit', 'Time', 'Timestamp', 'ensure_time']
 
 
 class TimeUnit(StringEnum):
@@ -37,27 +37,26 @@ class TimeUnit(StringEnum):
         TOKEN (str): Tokens. Applicable for natural language processing (NLP) models.
         DURATION (str): Fraction of the training process complete, on ``[0.0, 1.0)``
     """
-    EPOCH = "ep"
-    BATCH = "ba"
-    SAMPLE = "sp"
-    TOKEN = "tok"
-    DURATION = "dur"
+    EPOCH = 'ep'
+    BATCH = 'ba'
+    SAMPLE = 'sp'
+    TOKEN = 'tok'
+    DURATION = 'dur'
 
 
 # regex for parsing integers / decimals / scientific notation
 _NUM_REGEX = r'-?[\d.]+(?:e-?\d+)?'
 
 # regex for parsing a time string.
-_TIME_STR_REGEX = re.compile(r'^(?:' + r'|'.join(fr"(?:({_NUM_REGEX})({time_unit.value}))" for time_unit in TimeUnit) +
+_TIME_STR_REGEX = re.compile(r'^(?:' + r'|'.join(fr'(?:({_NUM_REGEX})({time_unit.value}))' for time_unit in TimeUnit) +
                              r')$',
                              flags=re.IGNORECASE)
 
-TValue = TypeVar("TValue", int, float)
+TValue = TypeVar('TValue', int, float)
 
 
-class Time(Generic[TValue]):
-    """Time represents static durations of training time or points in the training process in terms of a
-    :class:`TimeUnit` enum (epochs, batches, samples, tokens, or duration).
+class Time(Generic[TValue], Serializable):
+    """Time represents static durations of training time in terms of a :class:`TimeUnit` enum.
 
     See the :doc:`Time Guide </trainer/time>` for more details on tracking time during training.
 
@@ -124,12 +123,14 @@ class Time(Generic[TValue]):
             value = cast(TValue, float(value))
         else:
             if not isinstance(value, int):
-                raise TypeError(f"value {value} is of type {type(value)}. Units {unit} require integer values.")
+                raise TypeError(f'value {value} is of type {type(value)}. Units {unit} require integer values.')
         self._value, self._unit = value, TimeUnit(unit)
 
     @classmethod
     def from_epoch(cls, epoch: int) -> Time:
-        """Create a :class:`Time` with units of :attr:`TimeUnit.EPOCH`. Equivalent to ``Time(epoch, TimeUnit.EPOCH)``.
+        """Create a :class:`Time` with units of :attr:`TimeUnit.EPOCH`.
+
+        Equivalent to ``Time(epoch, TimeUnit.EPOCH)``.
 
         Args:
             epoch (int): Number of epochs.
@@ -141,7 +142,9 @@ class Time(Generic[TValue]):
 
     @classmethod
     def from_batch(cls, batch: int) -> Time:
-        """Create a :class:`Time` with units of :attr:`TimeUnit.BATCH`. Equivalent to ``Time(batch, TimeUnit.BATCH)``.
+        """Create a :class:`Time` with units of :attr:`TimeUnit.BATCH`.
+
+        Equivalent to ``Time(batch, TimeUnit.BATCH)``.
 
         Args:
             batch (int): Number of batches.
@@ -153,8 +156,9 @@ class Time(Generic[TValue]):
 
     @classmethod
     def from_sample(cls, sample: int) -> Time:
-        """Create a :class:`Time` with units of :attr:`TimeUnit.SAMPLE`. Equivalent to ``Time(sample,
-        TimeUnit.SAMPLE)``.
+        """Create a :class:`Time` with units of :attr:`TimeUnit.SAMPLE`.
+
+        Equivalent to ``Time(sample, TimeUnit.SAMPLE)``.
 
         Args:
             sample (int): Number of samples.
@@ -166,7 +170,9 @@ class Time(Generic[TValue]):
 
     @classmethod
     def from_token(cls, token: int) -> Time:
-        """Create a :class:`Time` with units of :attr:`TimeUnit.TOKEN`. Equivalent to ``Time(sample, TimeUnit.TOKEN)``.
+        """Create a :class:`Time` with units of :attr:`TimeUnit.TOKEN`.
+
+        Equivalent to ``Time(sample, TimeUnit.TOKEN)``.
 
         Args:
             token (int): Number of tokens.
@@ -178,8 +184,9 @@ class Time(Generic[TValue]):
 
     @classmethod
     def from_duration(cls, duration: float) -> Time:
-        """Create a :class:`Time` with units of :attr:`TimeUnit.DURATION`. Equivalent to ``Time(duration,
-        TimeUnit.DURATION)``.
+        """Create a :class:`Time` with units of :attr:`TimeUnit.DURATION`.
+
+        Equivalent to ``Time(duration, TimeUnit.DURATION)``.
 
         Args:
             duration (float): Duration of the training process. Should be on ``[0, 1)``
@@ -202,10 +209,10 @@ class Time(Generic[TValue]):
         return self._unit
 
     def __repr__(self) -> str:
-        return f"{self.__class__.__name__}({self.value}, {self.unit})"
+        return f'{self.__class__.__name__}({self.value}, {self.unit})'
 
     def __str__(self) -> str:
-        return f"{self.value}{self.unit.value}"
+        return f'{self.value}{self.unit.value}'
 
     def to_timestring(self):
         """Get the time-string representation.
@@ -230,7 +237,7 @@ class Time(Generic[TValue]):
             other_parsed = Time.from_timestring(other)
             return other_parsed
 
-        raise TypeError(f"Cannot convert type {other} to {self.__class__.__name__}")
+        raise TypeError(f'Cannot convert type {other} to {self.__class__.__name__}')
 
     def _cmp(self, other: Union[int, float, Time, str]) -> int:
         # When doing comparisions, and other is an integer (or float), we can safely infer
@@ -243,7 +250,7 @@ class Time(Generic[TValue]):
             other = type(self)(other, self.unit)
         other = self._parse(other)
         if self.unit != other.unit:
-            raise RuntimeError(f"Cannot compare {self} to {other} since they have different units.")
+            raise RuntimeError(f'Cannot compare {self} to {other} since they have different units.')
         if self.value < other.value:
             return -1
         if self.value == other.value:
@@ -272,7 +279,7 @@ class Time(Generic[TValue]):
     def __add__(self, other: Union[int, float, Time, str]) -> Time[TValue]:
         other = self._parse(other)
         if self.unit != other.unit:
-            raise RuntimeError(f"Cannot add {self} to {other} since they have different units.")
+            raise RuntimeError(f'Cannot add {self} to {other} since they have different units.')
         return Time(self.value + other.value, self.unit)
 
     def __radd__(self, other: Union[int, float, Time, str]) -> Time[TValue]:
@@ -281,7 +288,7 @@ class Time(Generic[TValue]):
     def __sub__(self, other: Union[int, float, Time, str]) -> Time[TValue]:
         other = self._parse(other)
         if self.unit != other.unit:
-            raise RuntimeError(f"Cannot subtract {other} from {self} since they have different units.")
+            raise RuntimeError(f'Cannot subtract {other} from {self} since they have different units.')
         return Time(self.value - other.value, self.unit)
 
     def __rsub__(self, other: Union[int, float, Time, str]) -> Time[TValue]:
@@ -304,7 +311,7 @@ class Time(Generic[TValue]):
             return Time(type(self.value)(self.value / other), self.unit)
         other = self._parse(other)
         if self.unit != other.unit:
-            raise RuntimeError(f"Cannot divide {self} by {other} since they have different units.")
+            raise RuntimeError(f'Cannot divide {self} by {other} since they have different units.')
         return Time(self.value / other.value, TimeUnit.DURATION)
 
     def __mul__(self, other: object):
@@ -313,7 +320,7 @@ class Time(Generic[TValue]):
             return Time(type(self.value)(self.value * other), self.unit)
         other = self._parse(other)
         if other.unit != TimeUnit.DURATION and self.unit != TimeUnit.DURATION:
-            raise RuntimeError(f"Multiplication is supported only if one of the units is Duration")
+            raise RuntimeError(f'Multiplication is supported only if one of the units is Duration')
         real_unit = self.unit if other.unit == TimeUnit.DURATION else other.unit
         real_type = float if real_unit == TimeUnit.DURATION else int
         return Time(real_type(self.value * other.value), real_unit)
@@ -326,8 +333,9 @@ class Time(Generic[TValue]):
 
     @classmethod
     def from_timestring(cls, timestring: str) -> Time:
-        """Parse a time string into a :class:`Time` instance. A time string is a numerical value followed by the value
-        of a :class:`TimeUnit` enum. For example:
+        """Parse a time string into a :class:`Time` instance.
+
+        A time string is a numerical value followed by the value of a :class:`TimeUnit` enum. For example:
 
         >>> Time.from_timestring("5ep")  # describes 5 epochs.
         Time(5, TimeUnit.EPOCH)
@@ -341,23 +349,25 @@ class Time(Generic[TValue]):
         """
         match = _TIME_STR_REGEX.findall(timestring)
         if len(match) != 1:
-            raise ValueError(f"Invalid time string: {timestring}")
+            raise ValueError(f'Invalid time string: {timestring}')
         match = match[0]
         match = [x for x in match if x != '']
-        assert len(match) == 2, "each match should have a number followed by the key"
+        assert len(match) == 2, 'each match should have a number followed by the key'
         value = match[0]
         unit = TimeUnit(match[1])
         value = float(value)  # always parsing first as float b/c it could be scientific notation
         if unit != TimeUnit.DURATION:
             if int(value) != value:
-                raise TypeError(f"value {value} is not an integer. Units {unit} require integer values.")
+                raise TypeError(f'value {value} is not an integer. Units {unit} require integer values.')
             value = int(value)
         return cls(value, unit)
 
 
 class Timestamp(Serializable):
-    """Timestamp represents a snapshot of the current training progress, in terms of epochs, batches,
-    samples, and tokens. Timestamps are not updated in-place.
+    """Timestamp represents a snapshot of the current training progress.
+
+    The timestamp measures training progress in terms of epochs, batches, samples, tokens, and wall clock time.
+    Timestamps are not updated in-place.
 
     See the :doc:`Time Guide </trainer/time>` for more details on tracking time during training.
 
@@ -389,40 +399,40 @@ class Timestamp(Serializable):
     ):
         epoch = ensure_time(epoch, TimeUnit.EPOCH)
         if epoch.unit != TimeUnit.EPOCH:
-            raise ValueError(f"The `epoch` argument has units of {epoch.unit}; not {TimeUnit.EPOCH}.")
+            raise ValueError(f'The `epoch` argument has units of {epoch.unit}; not {TimeUnit.EPOCH}.')
         self._epoch = epoch
 
         batch = ensure_time(batch, TimeUnit.BATCH)
         if batch.unit != TimeUnit.BATCH:
-            raise ValueError(f"The `batch` argument has units of {batch.unit}; not {TimeUnit.BATCH}.")
+            raise ValueError(f'The `batch` argument has units of {batch.unit}; not {TimeUnit.BATCH}.')
         self._batch = batch
 
         sample = ensure_time(sample, TimeUnit.SAMPLE)
         if sample.unit != TimeUnit.SAMPLE:
-            raise ValueError(f"The `sample` argument has units of {sample.unit}; not {TimeUnit.SAMPLE}.")
+            raise ValueError(f'The `sample` argument has units of {sample.unit}; not {TimeUnit.SAMPLE}.')
         self._sample = sample
 
         token = ensure_time(token, TimeUnit.TOKEN)
         if token.unit != TimeUnit.TOKEN:
-            raise ValueError(f"The `token` argument has units of {token.unit}; not {TimeUnit.TOKEN}.")
+            raise ValueError(f'The `token` argument has units of {token.unit}; not {TimeUnit.TOKEN}.')
         self._token = token
 
         batch_in_epoch = ensure_time(batch_in_epoch, TimeUnit.BATCH)
         if batch_in_epoch.unit != TimeUnit.BATCH:
-            raise ValueError((f"The `batch_in_epoch` argument has units of {batch_in_epoch.unit}; "
-                              f"not {TimeUnit.BATCH}."))
+            raise ValueError((f'The `batch_in_epoch` argument has units of {batch_in_epoch.unit}; '
+                              f'not {TimeUnit.BATCH}.'))
         self._batch_in_epoch = batch_in_epoch
 
         sample_in_epoch = ensure_time(sample_in_epoch, TimeUnit.SAMPLE)
         if sample_in_epoch.unit != TimeUnit.SAMPLE:
-            raise ValueError((f"The `sample_in_epoch` argument has units of {sample_in_epoch.unit}; "
-                              f"not {TimeUnit.SAMPLE}."))
+            raise ValueError((f'The `sample_in_epoch` argument has units of {sample_in_epoch.unit}; '
+                              f'not {TimeUnit.SAMPLE}.'))
         self._sample_in_epoch = sample_in_epoch
 
         token_in_epoch = ensure_time(token_in_epoch, TimeUnit.TOKEN)
         if token_in_epoch.unit != TimeUnit.TOKEN:
-            raise ValueError((f"The `token_in_epoch` argument has units of {token_in_epoch.unit}; "
-                              f"not {TimeUnit.TOKEN}."))
+            raise ValueError((f'The `token_in_epoch` argument has units of {token_in_epoch.unit}; '
+                              f'not {TimeUnit.TOKEN}.'))
         self._token_in_epoch = token_in_epoch
 
         if total_wct is None:
@@ -439,48 +449,53 @@ class Timestamp(Serializable):
 
     def state_dict(self) -> Dict[str, Any]:
         return {
-            "epoch": self.epoch.value,
-            "batch": self.batch.value,
-            "sample": self.sample.value,
-            "token": self.token.value,
-            "batch_in_epoch": self.batch_in_epoch.value,
-            "sample_in_epoch": self.sample_in_epoch.value,
-            "token_in_epoch": self.token_in_epoch.value,
-            "total_wct": self.total_wct,
-            "epoch_wct": self.epoch_wct,
-            "batch_wct": self.batch_wct,
+            'epoch': self.epoch.value,
+            'batch': self.batch.value,
+            'sample': self.sample.value,
+            'token': self.token.value,
+            'batch_in_epoch': self.batch_in_epoch.value,
+            'sample_in_epoch': self.sample_in_epoch.value,
+            'token_in_epoch': self.token_in_epoch.value,
+            'total_wct': self.total_wct,
+            'epoch_wct': self.epoch_wct,
+            'batch_wct': self.batch_wct,
         }
 
     def get_state(self) -> Dict[str, Union[Time[int], datetime.timedelta]]:
+        """Returns all values of the timestamp object in a dictionary.
+
+        Returns:
+            Dict[str, Union[Time[int], datetime.timedelta]]: All values of the timestamp object.
+        """
         return {
-            "epoch": self.epoch,
-            "batch": self.batch,
-            "sample": self.sample,
-            "token": self.token,
-            "batch_in_epoch": self.batch_in_epoch,
-            "sample_in_epoch": self.sample_in_epoch,
-            "token_in_epoch": self.token_in_epoch,
-            "total_wct": self.total_wct,
-            "epoch_wct": self.epoch_wct,
-            "batch_wct": self.batch_wct,
+            'epoch': self.epoch,
+            'batch': self.batch,
+            'sample': self.sample,
+            'token': self.token,
+            'batch_in_epoch': self.batch_in_epoch,
+            'sample_in_epoch': self.sample_in_epoch,
+            'token_in_epoch': self.token_in_epoch,
+            'total_wct': self.total_wct,
+            'epoch_wct': self.epoch_wct,
+            'batch_wct': self.batch_wct,
         }
 
     def load_state_dict(self, state: Dict[str, Any]) -> None:
-        self._epoch = Time(state["epoch"], TimeUnit.EPOCH)
-        self._batch = Time(state["batch"], TimeUnit.BATCH)
-        self._sample = Time(state["sample"], TimeUnit.SAMPLE)
-        self._token = Time(state["token"], TimeUnit.TOKEN)
-        self._batch_in_epoch = Time(state["batch_in_epoch"], TimeUnit.BATCH)
-        self._sample_in_epoch = Time(state["sample_in_epoch"], TimeUnit.SAMPLE)
-        self._token_in_epoch = Time(state["token_in_epoch"], TimeUnit.TOKEN)
+        self._epoch = Time(state['epoch'], TimeUnit.EPOCH)
+        self._batch = Time(state['batch'], TimeUnit.BATCH)
+        self._sample = Time(state['sample'], TimeUnit.SAMPLE)
+        self._token = Time(state['token'], TimeUnit.TOKEN)
+        self._batch_in_epoch = Time(state['batch_in_epoch'], TimeUnit.BATCH)
+        self._sample_in_epoch = Time(state['sample_in_epoch'], TimeUnit.SAMPLE)
+        self._token_in_epoch = Time(state['token_in_epoch'], TimeUnit.TOKEN)
         # Wall clock time tracking was added in composer v0.7.0
         # Using conditional checks as not to break old checkpoints
-        if "total_wct" in state:
-            self._total_wct = state["total_wct"]
-        if "epoch_wct" in state:
-            self._epoch_wct = state["epoch_wct"]
-        if "batch_wct" in state:
-            self._batch_wct = state["batch_wct"]
+        if 'total_wct' in state:
+            self._total_wct = state['total_wct']
+        if 'epoch_wct' in state:
+            self._epoch_wct = state['epoch_wct']
+        if 'batch_wct' in state:
+            self._batch_wct = state['batch_wct']
 
     @property
     def epoch(self) -> Time[int]:
@@ -550,7 +565,7 @@ class Timestamp(Serializable):
             return self.sample
         if unit == TimeUnit.TOKEN:
             return self.token
-        raise ValueError(f"Invalid unit: {unit}")
+        raise ValueError(f'Invalid unit: {unit}')
 
     def _parse(self, other: object) -> Time:
         # parse ``other`` into a Time object
@@ -560,7 +575,7 @@ class Timestamp(Serializable):
             other_parsed = Time.from_timestring(other)
             return other_parsed
 
-        raise TypeError(f"Cannot convert type {other} to {self.__class__.__name__}")
+        raise TypeError(f'Cannot convert type {other} to {self.__class__.__name__}')
 
     def __eq__(self, other: object):
         if not isinstance(other, (Time, Timestamp, str)):
@@ -614,7 +629,7 @@ class Timestamp(Serializable):
         tokens: Union[int, Time] = 0,
         duration: Optional[datetime.timedelta] = None,
     ):
-        """Create a new :class:`.Timestamp`, with the batch, sample, and token counts properly incremented.
+        """Create a new :class:`.Timestamp`, advanced to the next batch.
 
         Equivalent to:
 
@@ -670,12 +685,10 @@ class Timestamp(Serializable):
         )
 
     def to_next_epoch(self):
-        """Create a new :class:`.Timestamp` incremented by one epoch and with
-        :attr:`batch_in_epoch`, :attr:`sample_in_epoch`, and :attr:`token_in_epoch` reset.
+        """Create a new :class:`.Timestamp`, advanced to the next epoch.
 
         Equivalent to:
 
-
         .. testsetup::
 
             from composer.core.time import Timestamp
@@ -718,8 +731,9 @@ class Timestamp(Serializable):
         epoch_wct: Optional[datetime.timedelta] = None,
         batch_wct: Optional[datetime.timedelta] = None,
     ) -> Timestamp:
-        """Create a copy of the timestamp. Any specified values will override the existing values in the
-        returned copy.
+        """Create a copy of the timestamp.
+
+        Any specified values will override the existing values in the returned copy.
 
         Args:
             epoch (int | Time[int], optional): The epoch.
@@ -749,22 +763,22 @@ class Timestamp(Serializable):
         )
 
     def __repr__(self) -> str:
-        return (f"Timestamp("
-                f"epoch={int(self.epoch)}, "
-                f"batch={int(self.batch)}, "
-                f"sample={int(self.sample)}, "
-                f"token={int(self.token)}, "
-                f"batch_in_epoch={int(self.batch_in_epoch)}, "
-                f"sample_in_epoch={int(self.sample_in_epoch)}, "
-                f"token_in_epoch={int(self.token_in_epoch)}, "
-                f"total_wct={repr(self.total_wct)}, "
-                f"epoch_wct={repr(self.epoch_wct)}, "
-                f"batch_wct={repr(self.batch_wct)}"
-                ")")
+        return (f'Timestamp('
+                f'epoch={int(self.epoch)}, '
+                f'batch={int(self.batch)}, '
+                f'sample={int(self.sample)}, '
+                f'token={int(self.token)}, '
+                f'batch_in_epoch={int(self.batch_in_epoch)}, '
+                f'sample_in_epoch={int(self.sample_in_epoch)}, '
+                f'token_in_epoch={int(self.token_in_epoch)}, '
+                f'total_wct={repr(self.total_wct)}, '
+                f'epoch_wct={repr(self.epoch_wct)}, '
+                f'batch_wct={repr(self.batch_wct)}'
+                ')')
 
 
 def ensure_time(maybe_time: Union[Time, str, int], int_unit: Union[TimeUnit, str]) -> Time:
-    """Ensure ``maybe_time`` is an instance of :class:`.Time`
+    """Ensure ``maybe_time`` is an instance of :class:`.Time`.
 
     Args:
         maybe_time (Time | str): A time string, integer, or instance of :class:`.Time`.
@@ -779,4 +793,4 @@ def ensure_time(maybe_time: Union[Time, str, int], int_unit: Union[TimeUnit, str
         return Time(maybe_time, int_unit)
     if isinstance(maybe_time, Time):
         return maybe_time
-    raise TypeError(f"Unsupported type for ensure_time: {type(maybe_time)}")
+    raise TypeError(f'Unsupported type for ensure_time: {type(maybe_time)}')
