@@ -1,123 +1,117 @@
 # Copyright 2022 MosaicML Composer authors
 # SPDX-License-Identifier: Apache-2.0
 
-"""C4 (Colossal Cleaned CommonCrawl) dataset.
+"""C4 (Colossal Cleaned Common Crawl) dataset.
 
 This dataset is a colossal, cleaned version of Common Crawl's web crawl corpus and it is based on the `Common Crawl
 <https://commoncrawl.org>`_ dataset.
 """
 import copy
 import logging
-from dataclasses import dataclass
+import os
 from functools import partial
 from itertools import chain, cycle
+from typing import Any, Dict, Optional
 
-import yahp as hp
-from torch.utils.data import DataLoader, IterableDataset, get_worker_info
+from torch.utils.data import IterableDataset, get_worker_info
 
-from composer.datasets.dataloader import DataLoaderHparams
-from composer.datasets.hparams import DatasetHparams
+from composer.datasets.streaming import StreamingDataset
 from composer.utils import dist
 from composer.utils.import_helpers import MissingConditionalImportError
 
 log = logging.getLogger(__name__)
 
-__all__ = ["C4Dataset", "C4DatasetHparams"]
+__all__ = ['C4Dataset', 'StreamingC4']
 
 
-@dataclass
-class C4DatasetHparams(DatasetHparams):
-    """Builds a :class:`.DataSpec` for the C4 (Colossal Cleaned CommonCrawl) dataset.
+class StreamingC4(StreamingDataset):
+    """
+    Implementation of the C4 (Colossal Cleaned Common Crawl) dataset using StreamingDataset.
 
     Args:
-        split (str): What split of the dataset to use. Either ``'train'`` or ``'validation'``. Default: ``None``.
-        num_samples (int): The number of post-processed token samples, used to set epoch size of the
-            :class:`torch.utils.data.IterableDataset`. Default: ``None``.
-        tokenizer_name (str): The name of the HuggingFace tokenizer to preprocess text with. Default: ``None``.
-        max_seq_len (int): The max sequence length of each token sample. Default: ``None``.
-        group_method (str): How to group text samples into token samples. Either `truncate` or `concat`.
-            Default: ``None``.
-        mlm (bool): Whether or not to use masked language modeling. Default: ``False``.
-        mlm_probability (float): If ``mlm=True``, the probability that tokens are masked. Default: ``0.15``.
-        shuffle (bool): Whether to shuffle the samples in the dataset. Currently, shards are assigned and consumed with
-            deterministic per-device shard order, but shuffling affects the order of samples via (per-device) shuffle
-            buffers. Default: ``False``.
-        shuffle_buffer_size (int): If ``shuffle=True``, samples are read into a buffer of this size (per-device), and
-            randomly sampled from there to produce shuffled samples. Default: ``10000``.
-        seed (int): If ``shuffle=True``, what seed to use for shuffling operations. Default: ``5``.
-        drop_last (bool): Whether to drop the last samples for the last batch. Default: ``True``.
-    Returns:
-        DataLoader: A PyTorch :class:`~torch.utils.data.DataLoader` object.
+        remote (str): Remote directory (S3 or local filesystem) where dataset is stored.
+        local (str): Local filesystem directory where dataset is cached during operation.
+        split (str): The dataset split to use, either 'train' or 'val'.
+        shuffle (bool): Whether to shuffle the samples in this dataset.
+        tokenizer_name (str): The name of the HuggingFace tokenizer to use to tokenize samples.
+        max_seq_len (int): The max sequence length of each token sample.
+        group_method (str): How to group text samples into token samples. Currently only supporting ``'truncate'``.
+        max_retries (int): Number of download re-attempts before giving up. Default: 2.
+        timeout (float): How long to wait for shard to download before raising an exception. Default: 120 sec.
+        batch_size (Optional[int]): Hint batch_size that will be used on each device's DataLoader. Default: ``None``.
     """
 
-    split: str = hp.optional("What split of the dataset to use. Either `train` or `validation`.", default=None)
-    num_samples: int = hp.optional(
-        "The number of post-processed token samples, used to set epoch size of the IterableDataset.", default=None)
-    tokenizer_name: str = hp.optional("The name of the HuggingFace tokenizer to preprocess text with.", default=None)
-    max_seq_len: int = hp.optional("The max sequence length of each token sample.", default=None)
-    group_method: str = hp.optional("How to group text samples into token samples. Either `truncate` or `concat`.",
-                                    default=None)
-    mlm: bool = hp.optional("Whether or not to use masked language modeling.", default=False)
-    mlm_probability: float = hp.optional("If `mlm=True`, the probability that tokens are masked.", default=0.15)
-    shuffle: bool = hp.optional(
-        "Whether to shuffle the samples in the dataset. Currently, shards are assigned and consumed with deterministic per-device shard order, but shuffling affects the order of samples via (per-device) shuffle buffers.",
-        default=True)
-    shuffle_buffer_size: int = hp.optional(
-        "If `shuffle=True`, samples are read into a buffer of this size (per-device), and randomly sampled from there to produce shuffled samples.",
-        default=10000)
-    seed: int = hp.optional("If `shuffle=True`, what seed to use for shuffling operations.", default=5)
-    drop_last: bool = hp.optional("Whether to drop the last samples for the last batch.", default=True)
+    def _decode(self, data: bytes) -> str:
+        return data.decode('utf-8')
 
-    def validate(self):
-        if self.split not in ["train", "validation"]:
-            raise ValueError(f"Unknown split: '{self.split}'")
-        if self.num_samples is None or self.num_samples <= 0:
-            raise ValueError(f"Must provide 'num_samples' > 0")
-        if self.tokenizer_name is None:
-            raise ValueError(f"Must provide 'tokenizer_name'")
-        if self.max_seq_len is None or self.max_seq_len <= 0:
-            raise ValueError(f"Must provide 'max_seq_len' > 0")
-        if self.group_method not in ["truncate", "concat"]:
-            raise ValueError(f"Unknown group_method: '{self.group_method}'. Must be 'truncate' or 'concat'")
-        if self.mlm and self.mlm_probability <= 0:
-            raise ValueError("Must provide a positive 'mlm_probability' when using masked language modeling.")
+    def _tokenize(self, text_sample):
+        if self.group_method == 'truncate':
+            truncation = True
+            padding = 'max_length'
+            max_length = self.max_seq_len
+        else:
+            truncation = False
+            padding = False
+            max_length = None
+        return self.tokenizer(text_sample['text'], truncation=truncation, padding=padding, max_length=max_length)
 
-    def initialize_object(self, batch_size: int, dataloader_hparams: DataLoaderHparams) -> DataLoader:
+    def __init__(self,
+                 remote: str,
+                 local: str,
+                 split: str,
+                 shuffle: bool,
+                 tokenizer_name: str,
+                 max_seq_len: int,
+                 group_method: str = 'truncate',
+                 max_retries: int = 2,
+                 timeout: float = 120,
+                 batch_size: Optional[int] = None):
+
+        # HF Transformers is needed to build the tokenizer
         try:
             import transformers
         except ImportError as e:
-            raise MissingConditionalImportError(extra_deps_group="nlp", conda_package="transformers") from e
+            raise MissingConditionalImportError(extra_deps_group='nlp', conda_package='transformers') from e
 
-        if dataloader_hparams.num_workers > 1:
-            log.warning("C4 Dataset not compatible with num_workers > 1. Overwriting value to num_workers=1")
-            dataloader_hparams.num_workers = 1
+        # Validation
+        if split not in ['train', 'val']:
+            raise ValueError(f"split='{split}' must be one of ['train', 'val'].")
+        if group_method not in ['truncate']:
+            raise ValueError(f"Only group_method='truncate' is supported at this time.")
 
-        # Get C4 dataset
-        c4_dataset = C4Dataset(split=self.split,
-                               num_samples=self.num_samples,
-                               tokenizer_name=self.tokenizer_name,
-                               max_seq_len=self.max_seq_len,
-                               group_method=self.group_method,
-                               shuffle=self.shuffle,
-                               shuffle_buffer_size=self.shuffle_buffer_size,
-                               seed=self.seed)
+        # Build StreamingDataset
+        decoders = {
+            'text': self._decode,
+            'timestamp': self._decode,
+            'url': self._decode,
+        }
+        super().__init__(remote=os.path.join(remote, split),
+                         local=os.path.join(local, split),
+                         shuffle=shuffle,
+                         decoders=decoders,
+                         max_retries=max_retries,
+                         timeout=timeout,
+                         batch_size=batch_size)
+        self.tokenizer_name = tokenizer_name
+        self.max_seq_len = max_seq_len
+        self.group_method = group_method
 
-        # Get collate_fn
-        collate_fn = transformers.DataCollatorForLanguageModeling(tokenizer=c4_dataset.tokenizer,
-                                                                  mlm=self.mlm,
-                                                                  mlm_probability=self.mlm_probability)
+        # Build tokenizer
+        self.tokenizer = transformers.AutoTokenizer.from_pretrained(self.tokenizer_name)
+        if self.tokenizer.pad_token is None:
+            # Some tokenizers (e.g. GPT2 tokenizer) have no padding token which causes bugs
+            self.tokenizer.pad_token = self.tokenizer.eos_token
 
-        return dataloader_hparams.initialize_object(
-            dataset=c4_dataset,  # type: ignore
-            batch_size=batch_size,
-            sampler=None,
-            drop_last=self.drop_last,
-            collate_fn=collate_fn)
+    def __getitem__(self, idx: int) -> Dict[str, Any]:
+        text_sample = super().__getitem__(idx)
+        token_sample = self._tokenize(text_sample)
+        # Skip any token grouping, currently only supporting group_method='truncate'
+        return token_sample
 
 
 class C4Dataset(IterableDataset):
     """Builds a streaming, sharded, sized :class:`torch.utils.data.IterableDataset` for the C4 (Colossal Cleaned
-    CommonCrawl) dataset. Used for pretraining autoregressive or masked language models. Text samples are streamed
+    Common Crawl) dataset. Used for pretraining autoregressive or masked language models. Text samples are streamed
     directly from the cloud using HuggingFace's C4 Dataset with streaming backend (See
     https://huggingface.co/datasets/c4 for more details). The text samples are then shuffled, tokenized, and grouped on-
     the-fly.
@@ -151,7 +145,7 @@ class C4Dataset(IterableDataset):
             import datasets
             import transformers
         except ImportError as e:
-            raise MissingConditionalImportError(extra_deps_group="nlp", conda_package="datasets transformers") from e
+            raise MissingConditionalImportError(extra_deps_group='nlp', conda_package='datasets transformers') from e
 
         self.split = split
         self.num_samples = num_samples
@@ -164,20 +158,20 @@ class C4Dataset(IterableDataset):
 
         # Metadata
         c4_metadata = {
-            "train": {
-                "num_shards": 1024,
-                "approx_samples_per_shard": 356317,
+            'train': {
+                'num_shards': 1024,
+                'approx_samples_per_shard': 356317,
             },
-            "validation": {
-                "num_shards": 8,
-                "approx_samples_per_shard": 45576,
+            'validation': {
+                'num_shards': 8,
+                'approx_samples_per_shard': 45576,
             }
         }
         if self.split in c4_metadata:
-            self.num_shards = c4_metadata[self.split]["num_shards"]
-            self.approx_samples_per_shard = c4_metadata[self.split]["approx_samples_per_shard"]
+            self.num_shards = c4_metadata[self.split]['num_shards']
+            self.approx_samples_per_shard = c4_metadata[self.split]['approx_samples_per_shard']
         else:
-            raise ValueError(f"Unknown split={self.split}, expected one of {list(c4_metadata.keys())}.")
+            raise ValueError(f'Unknown split={self.split}, expected one of {list(c4_metadata.keys())}.')
 
         # Set dataset size
         self.world_size = dist.get_world_size()
@@ -186,21 +180,21 @@ class C4Dataset(IterableDataset):
         if self.num_samples % self.world_size != 0:
             new_num_samples = self.num_samples_per_device * self.world_size
             log.warning(
-                f"Num samples will be truncated from {num_samples}->{new_num_samples} to maintain divisibility across {self.world_size} devices."
+                f'Num samples will be truncated from {num_samples}->{new_num_samples} to maintain divisibility across {self.world_size} devices.'
             )
             self.num_samples = new_num_samples
 
         # Try and detect if num_samples is larger than original dataset
         original_approx_samples = self.num_shards * self.approx_samples_per_shard
-        if self.num_samples > original_approx_samples and self.group_method == "truncate":
+        if self.num_samples > original_approx_samples and self.group_method == 'truncate':
             log.warning(
                 f"Num samples was set to {self.num_samples} with group_method 'truncate' but split '{split}' has only {original_approx_samples}. "
-                f"The original dataset will cycle until the new nominal length of {self.num_samples}.")
-        if self.group_method == "concat":
+                f'The original dataset will cycle until the new nominal length of {self.num_samples}.')
+        if self.group_method == 'concat':
             log.warning(
                 f"When using group_method 'concat', sequential token samples are concatenated and chunked into fixed-length samples of size max_seq_len={self.max_seq_len}. "
-                f"In general we cannot detect ahead-of-time if your setting of num_samples={self.num_samples} will be larger than the original dataset, "
-                f"but if it is larger, the original dataset will cycle until the new nominal length of {self.num_samples}."
+                f'In general we cannot detect ahead-of-time if your setting of num_samples={self.num_samples} will be larger than the original dataset, '
+                f'but if it is larger, the original dataset will cycle until the new nominal length of {self.num_samples}.'
             )
 
         # Build tokenizer
@@ -210,10 +204,10 @@ class C4Dataset(IterableDataset):
             self.tokenizer.pad_token = self.tokenizer.eos_token
 
         # Load and shard dataset
-        text_dataset = datasets.load_dataset(path="c4", name="en", split=split, streaming=True)
+        text_dataset = datasets.load_dataset(path='c4', name='en', split=split, streaming=True)
         text_dataset = self._shard_dataset(text_dataset)
         if not isinstance(text_dataset, datasets.IterableDataset):
-            raise ValueError("Unable to build sharded Huggingface C4 Dataset.")
+            raise ValueError('Unable to build sharded Huggingface C4 Dataset.')
 
         # Map text samples to token samples
         # NOTE: Mapping is executed in batched mode for better CPU utilization,
@@ -268,7 +262,7 @@ class C4Dataset(IterableDataset):
             from datasets.iterable_dataset import _BaseExamplesIterable
             from datasets.iterable_dataset import iterable_dataset as hf_iterable_dataset
         except ImportError as e:
-            raise MissingConditionalImportError(extra_deps_group="nlp", conda_package="datasets") from e
+            raise MissingConditionalImportError(extra_deps_group='nlp', conda_package='datasets') from e
 
         class RepeatExamplesIterable(_BaseExamplesIterable):
 
@@ -307,19 +301,19 @@ class C4Dataset(IterableDataset):
         # Verify # of shards
         filepaths = dataset._ex_iterable.kwargs['filepaths']
         if self.num_shards != len(filepaths):
-            raise ValueError(f"Found {len(filepaths)} shards, expected {self.num_shards}")
+            raise ValueError(f'Found {len(filepaths)} shards, expected {self.num_shards}')
 
         # Determine how to allocate devices to shards
         devices_per_shard = 1
         if self.num_shards < self.world_size:
             log.warning(
-                f"Not enough unique shards ({self.num_shards}) for world size ({self.world_size}). Splitting shards among devices."
+                f'Not enough unique shards ({self.num_shards}) for world size ({self.world_size}). Splitting shards among devices.'
             )
             if self.world_size % self.num_shards != 0:
-                raise ValueError(f"Cannot evenly split {self.num_shards} shards among {self.world_size} devices")
+                raise ValueError(f'Cannot evenly split {self.num_shards} shards among {self.world_size} devices')
             devices_per_shard = self.world_size // self.num_shards
         elif self.num_shards % self.world_size != 0:
-            raise ValueError(f"Cannot evenly split {self.num_shards} shards among {self.world_size} devices")
+            raise ValueError(f'Cannot evenly split {self.num_shards} shards among {self.world_size} devices')
         shard_offset = self.rank // devices_per_shard
         device_offset = self.rank % devices_per_shard
 
@@ -340,7 +334,7 @@ class C4Dataset(IterableDataset):
 
     # Use the initialized HF tokenizer to convert a text batch to a token batch
     def _tokenize(self, text_batch):
-        if self.group_method == "truncate":
+        if self.group_method == 'truncate':
             truncation = True
             padding = 'max_length'
             max_length = self.max_seq_len
@@ -348,7 +342,7 @@ class C4Dataset(IterableDataset):
             truncation = False
             padding = False
             max_length = None
-        return self.tokenizer(text_batch["text"], truncation=truncation, padding=padding, max_length=max_length)
+        return self.tokenizer(text_batch['text'], truncation=truncation, padding=padding, max_length=max_length)
 
     # Prepare a batch of token samples for pretraining, by grouping them into fixed-length token samples, with either 'truncate' or 'concat' group methods.
     # If using 'truncate', each token sample is padded/truncated to 'self.max_seq_len', and there is no mixing between adjacent token samples.
@@ -359,10 +353,10 @@ class C4Dataset(IterableDataset):
     # Using 'concat' will alter the number of token samples in the iterable dataset, and differently per-device,
     # so we require the user to provide a 'self.num_samples' limit to ensure epoch-boundary synchronization across devices.
     def _group_tokens(self, token_batch):
-        if self.group_method == "truncate":
+        if self.group_method == 'truncate':
             # No processing needed, as 'self._tokenize()' has already padded / truncated each token sample to 'self.max_seq_len'
             return token_batch
-        elif self.group_method == "concat":
+        elif self.group_method == 'concat':
             # Concatenate all tokens.
             concat_tokens = {}
             num_tokens = None
@@ -372,11 +366,11 @@ class C4Dataset(IterableDataset):
                 if num_tokens is None:
                     num_tokens = len(concat_v)
                 elif num_tokens != len(concat_v):
-                    raise ValueError("Not all values in concat_tokens dict have same len()")
+                    raise ValueError('Not all values in concat_tokens dict have same len()')
                 else:
                     pass
             if num_tokens is None:
-                raise ValueError("Failed to determine num_tokens.")
+                raise ValueError('Failed to determine num_tokens.')
 
             # We drop the small remainder of tokens at the end of the batch.
             if num_tokens >= self.max_seq_len:
