@@ -13,7 +13,7 @@ from composer.core.callback import Callback
 from composer.core.state import State
 from composer.loggers.logger import LogLevel
 
-__all__ = ["LoggerDestination"]
+__all__ = ['LoggerDestination']
 
 
 class LoggerDestination(Callback, ABC):
@@ -23,9 +23,7 @@ class LoggerDestination(Callback, ABC):
     :class:`~composer.core.event.Event`. For example, it may be helpful to run on
     :attr:`~composer.core.event.Event.EPOCH_END` to perform any flushing at the end of every epoch.
 
-    Example
-    -------
-
+    Example:
     .. doctest::
 
         >>> from composer.loggers import LoggerDestination
@@ -38,10 +36,6 @@ class LoggerDestination(Callback, ABC):
         ...     loggers=[logger]
         ... )
         Batch 0: {'rank_zero_seed': ...}
-
-    .. testcleanup::
-
-        trainer.engine.close()
     """
 
     def log_data(self, state: State, log_level: LogLevel, data: Dict[str, Any]):
@@ -107,43 +101,11 @@ class LoggerDestination(Callback, ABC):
         del state, log_level, artifact_name, file_path, overwrite  # unused
         pass
 
-    def log_symlink_artifact(
-        self,
-        state: State,
-        log_level: LogLevel,
-        existing_artifact_name: str,
-        symlink_artifact_name: str,
-        overwrite: bool,
-    ):
-        """Handle creating a symlink of a file artifact stored at ``existing_artifact_name`` to an artifact named
-        ``symlink_artifact_name``.
-
-        Subclasses should implement this method to symlink logged files. However, not all loggers need to implement this
-        method. For example, the :class:`~composer.loggers.tqdm_logger.TQDMLogger` does not implement this method, as it
-        cannot handle file artifacts and thus does not need to do any special symlinking.
-
-        .. note::
-
-            *   This method will block the training loop. For optimal performance, it is recommended that this
-                method enqueue creating the symlink in the background and return immediately.
-                Then, use a background thread(s) or process(s) to read from this queue to perform any I/O.
-
-        Args:
-            state (State): The training state.
-            log_level (Union[str, LogLevel]): A :class:`LogLevel`.
-            existing_artifact_name (str): The name of symlinked artifact.
-            symlink_artifact_name (str): The symlink name of artifact.
-            overwrite (bool, optional): Whether to overwrite an existing artifact with the same ``symlink_artifact_name``.
-                (default: ``False``)
-        """
-        del state, log_level, existing_artifact_name, symlink_artifact_name, overwrite  # unused
-        pass
-
     def get_file_artifact(
         self,
         artifact_name: str,
         destination: str,
-        chunk_size: int = 2**20,
+        overwrite: bool = False,
         progress_bar: bool = True,
     ):
         """Handle downloading an artifact named ``artifact_name`` to ``destination``.
@@ -151,9 +113,9 @@ class LoggerDestination(Callback, ABC):
         Args:
             artifact_name (str): The name of the artifact.
             destination (str): The destination filepath.
-            chunk_size (int, optional): Chunk size (in bytes). Ignored if ``path`` is a local file. (default: 1MB)
+            overwrite (bool): Whether to overwrite an existing file at ``destination``. Defaults to ``False``.
             progress_bar (bool, optional): Whether to show a progress bar. Ignored if ``path`` is a local file.
                 (default: ``True``)
         """
-        del artifact_name, destination, chunk_size, progress_bar  # unused
+        del artifact_name, destination, overwrite, progress_bar  # unused
         raise NotImplementedError
