@@ -7,6 +7,6 @@ from composer.metrics.metrics import CrossEntropy, Dice, LossMetric, MIoU
 from composer.metrics.nlp import BinaryF1Score, HFCrossEntropy, LanguageCrossEntropy, MaskedAccuracy, Perplexity
 
 __all__ = [
-    "MIoU", "Dice", "CrossEntropy", "LossMetric", "Perplexity", "BinaryF1Score", "HFCrossEntropy",
-    "LanguageCrossEntropy", "MaskedAccuracy"
+    'MIoU', 'Dice', 'CrossEntropy', 'LossMetric', 'Perplexity', 'BinaryF1Score', 'HFCrossEntropy',
+    'LanguageCrossEntropy', 'MaskedAccuracy'
 ]
