@@ -21,7 +21,7 @@ if TYPE_CHECKING:
 
     from composer.core.types import Batch
 
-__all__ = ["GPT2Model"]
+__all__ = ['GPT2Model']
 
 
 class GPT2Model(ComposerTransformer):
@@ -57,7 +57,7 @@ class GPT2Model(ComposerTransformer):
                  gradient_checkpointing: bool = False) -> None:
 
         if tokenizer is None:
-            model_inputs = {"input_ids", "attention_mask"}
+            model_inputs = {'input_ids', 'attention_mask'}
         else:
             model_inputs = set(tokenizer.model_input_names)
 
