@@ -13,7 +13,7 @@ from composer.models.model_hparams import ModelHparams
 from composer.models.timm.model import Timm
 from composer.utils.import_helpers import MissingConditionalImportError
 
-__all__ = ["TimmHparams"]
+__all__ = ['TimmHparams']
 
 
 @dataclass
@@ -33,33 +33,35 @@ class TimmHparams(ModelHparams):
         bn_eps (float, optional): BatchNorm epsilon override (model default if ``None``). Default: ``None``.
     """
 
-    model_name: str = hp.optional(
+    model_name: Optional[str] = hp.optional(
         textwrap.dedent("""\
         timm model name e.g: 'resnet50', list of models can be found at
         https://github.com/rwightman/pytorch-image-models"""),
         default=None,
     )
-    pretrained: bool = hp.optional("imagenet pretrained", default=False)
-    num_classes: int = hp.optional("The number of classes.  Needed for classification tasks", default=1000)
-    drop_rate: float = hp.optional("dropout rate", default=0.0)
-    drop_path_rate: Optional[float] = hp.optional("drop path rate (model default if None)", default=None)
-    drop_block_rate: Optional[float] = hp.optional("drop block rate (model default if None)", default=None)
+    pretrained: bool = hp.optional('imagenet pretrained', default=False)
+    num_classes: int = hp.optional('The number of classes.  Needed for classification tasks', default=1000)
+    drop_rate: float = hp.optional('dropout rate', default=0.0)
+    drop_path_rate: Optional[float] = hp.optional('drop path rate (model default if None)', default=None)
+    drop_block_rate: Optional[float] = hp.optional('drop block rate (model default if None)', default=None)
     global_pool: Optional[str] = hp.optional(
-        "Global pool type, one of (fast, avg, max, avgmax, avgmaxc). Model default if None.", default=None)
-    bn_momentum: Optional[float] = hp.optional("BatchNorm momentum override (model default if not None)", default=None)
-    bn_eps: Optional[float] = hp.optional("BatchNorm epsilon override (model default if not None)", default=None)
+        'Global pool type, one of (fast, avg, max, avgmax, avgmaxc). Model default if None.', default=None)
+    bn_momentum: Optional[float] = hp.optional('BatchNorm momentum override (model default if not None)', default=None)
+    bn_eps: Optional[float] = hp.optional('BatchNorm epsilon override (model default if not None)', default=None)
 
     def validate(self):
         if self.model_name is None:
             try:
                 import timm
             except ImportError as e:
-                raise MissingConditionalImportError(extra_deps_group="timm",
-                                                    conda_package="timm >=0.5.4",
+                raise MissingConditionalImportError(extra_deps_group='timm',
+                                                    conda_package='timm >=0.5.4',
                                                     conda_channel=None) from e
-            raise ValueError(f"model must be one of {timm.models.list_models()}")
+            raise ValueError(f'model must be one of {timm.models.list_models()}')
 
     def initialize_object(self):
+        if self.model_name is None:
+            raise ValueError('model_name must be specified')
         return Timm(model_name=self.model_name,
                     pretrained=self.pretrained,
                     num_classes=self.num_classes,
