@@ -23,21 +23,19 @@ from torch.optim.lr_scheduler import LambdaLR
 from composer.core import State, Time, TimeUnit
 from composer.core.types import PyTorchScheduler
 
-try:
-    from typing import Protocol
-except ImportError:
-    Protocol = object  # Protocol is not available in python 3.7
-
 if TYPE_CHECKING:
     from typing import Protocol
+else:
+    # subclasses of Protocol cannot be instantiated in Python 3.8
+    Protocol = object
 
 log = logging.getLogger(__name__)
 
 __all__ = [
-    "ComposerScheduler", "compile_composer_scheduler", "StepScheduler", "MultiStepScheduler", "ConstantScheduler",
-    "LinearScheduler", "ExponentialScheduler", "CosineAnnealingScheduler", "CosineAnnealingWarmRestartsScheduler",
-    "PolynomialScheduler", "MultiStepWithWarmupScheduler", "LinearWithWarmupScheduler",
-    "CosineAnnealingWithWarmupScheduler", "PolynomialWithWarmupScheduler"
+    'ComposerScheduler', 'compile_composer_scheduler', 'StepScheduler', 'MultiStepScheduler', 'ConstantScheduler',
+    'LinearScheduler', 'ExponentialScheduler', 'CosineAnnealingScheduler', 'CosineAnnealingWarmRestartsScheduler',
+    'PolynomialScheduler', 'MultiStepWithWarmupScheduler', 'ConstantWithWarmupScheduler', 'LinearWithWarmupScheduler',
+    'CosineAnnealingWithWarmupScheduler', 'PolynomialWithWarmupScheduler'
 ]
 
 
@@ -131,11 +129,11 @@ def _convert_time(time: Union[str, Time[int], Time[float]], state: State, ssr: f
     if isinstance(time, str):
         time = Time.from_timestring(time)
 
-    assert state.max_duration is not None, "max_duration should be set whenever schedulers are invoked"
+    assert state.max_duration is not None, 'max_duration should be set whenever schedulers are invoked'
 
     if time.unit == TimeUnit.DURATION:
         if state.dataloader_len is None:
-            raise RuntimeError("Cannot convert time, as state.dataloader_len is None.")
+            raise RuntimeError('Cannot convert time, as state.dataloader_len is None.')
         if state.max_duration.unit == TimeUnit.EPOCH:
             return Time(int(time.value * int(state.dataloader_len) * state.max_duration.value), TimeUnit.BATCH)
         return Time(int(time.value * state.max_duration.value), state.max_duration.unit)
@@ -145,7 +143,7 @@ def _convert_time(time: Union[str, Time[int], Time[float]], state: State, ssr: f
         # e.g. if max_duration = 1ep, then any SSR would result in a new duration of 0.
         # so, convert the time into batches
         if state.dataloader_len is None:
-            raise RuntimeError("Cannot convert time, as state.dataloader_len is None.")
+            raise RuntimeError('Cannot convert time, as state.dataloader_len is None.')
         time = Time(value=time.value * int(state.dataloader_len), unit=TimeUnit.BATCH)
 
     return Time(value=int(time.value * ssr), unit=time.unit)
@@ -166,10 +164,9 @@ def compile_composer_scheduler(scheduler: ComposerScheduler, state: State, ssr:
     Returns:
         compiled_scheduler (PyTorchScheduler): The scheduler, in a form compatible with PyTorch scheduler interfaces.
     """
-
     optimizers = state.optimizers
     if len(optimizers) != 1:
-        raise NotImplementedError("Providing functional schedulers is unsupported with multiple optimizers.")
+        raise NotImplementedError('Providing functional schedulers is unsupported with multiple optimizers.')
     optimizer = optimizers[0]
 
     scheduler_sig = inspect.signature(scheduler)
@@ -284,7 +281,7 @@ class ConstantScheduler(ComposerScheduler):
         t_max (str | Time): Duration of this scheduler. Default = ``"1dur"``.
     """
 
-    def __init__(self, alpha: float = 1.0, t_max: Union[str, Time] = "1dur") -> None:
+    def __init__(self, alpha: float = 1.0, t_max: Union[str, Time] = '1dur') -> None:
         self.alpha = alpha
         self.t_max = t_max
 
@@ -330,7 +327,7 @@ class LinearScheduler(ComposerScheduler):
         t_max (str | Time): The duration of this scheduler. Default = ``"1dur"``.
     """
 
-    def __init__(self, alpha_i: float = 1.0, alpha_f: float = 0.0, t_max: Union[str, Time] = "1dur"):
+    def __init__(self, alpha_i: float = 1.0, alpha_f: float = 0.0, t_max: Union[str, Time] = '1dur'):
         self.alpha_i = alpha_i
         self.alpha_f = alpha_f
         self.t_max = Time.from_timestring(t_max) if isinstance(t_max, str) else t_max
@@ -365,7 +362,7 @@ class ExponentialScheduler(ComposerScheduler):
         gamma (float): Multiplicative decay factor.
     """
 
-    def __init__(self, gamma: float, decay_period: Union[str, Time] = "1ep"):
+    def __init__(self, gamma: float, decay_period: Union[str, Time] = '1ep'):
         self.gamma = gamma
         self.decay_period = decay_period
 
@@ -382,7 +379,6 @@ def _cosine_anneal(x: float, min_y: float = 0.0, max_y: float = 1.0) -> float:
     Curve is cos(x) on domain [0, pi], stretched to the domain [0, 1] and range [min_y, max_y]. Additionally, param x is
     clipped to the interval [0, 1]
     """
-
     x = min(max(x, 0.0), 1.0)
     return min_y + (max_y - min_y) * (1 + math.cos(x * math.pi)) / 2
 
@@ -411,7 +407,7 @@ class CosineAnnealingScheduler(ComposerScheduler):
         alpha_f (float): Learning rate multiplier to decay to. Default = ``0.0``.
     """
 
-    def __init__(self, t_max: Union[str, Time] = "1dur", alpha_f: float = 0.0):
+    def __init__(self, t_max: Union[str, Time] = '1dur', alpha_f: float = 0.0):
         self.t_max = t_max
         self.alpha_f = alpha_f
 
@@ -465,7 +461,7 @@ class CosineAnnealingWarmRestartsScheduler(ComposerScheduler):
         while current_interval_end <= state.timestamp.get(current_interval_end.unit):
             if current_interval_len.value == 0:
                 raise ValueError(
-                    "Interval between restarts for cosine annealing/warm restarts scheduler has decayed to 0.")
+                    'Interval between restarts for cosine annealing/warm restarts scheduler has decayed to 0.')
 
             current_interval_len = Time(value=int(self.t_mult * current_interval_len.value),
                                         unit=current_interval_len.unit)
@@ -501,7 +497,7 @@ class PolynomialScheduler(ComposerScheduler):
         alpha_f (float): Learning rate multiplier to decay to. Default = ``0.0``.
     """
 
-    def __init__(self, power: float, t_max: Union[str, Time] = "1dur", alpha_f: float = 0.0):
+    def __init__(self, power: float, t_max: Union[str, Time] = '1dur', alpha_f: float = 0.0):
         self.t_max = t_max
         self.power = power
         self.alpha_f = alpha_f
@@ -572,6 +568,41 @@ class MultiStepWithWarmupScheduler(ComposerScheduler):
         return self.step_scheduler(state, ssr)
 
 
+class ConstantWithWarmupScheduler(ComposerScheduler):
+    r"""Maintains a fixed learning rate, with an initial warmup.
+
+    This scheduler is based on  :class:`~torch.optim.lr_scheduler.ConstantLR` from PyTorch, with an added warmup.
+
+    Starts with a linear warmup over ``t_warmup`` time, then simply maintains a learning rate factor of 1 for the entire training
+    duration. However, both the factor and the duration of this scheduler can be configured.
+
+    Specifically, the learning rate multiplier :math:`\alpha` can be expressed as:
+
+    .. math::
+        \alpha(t) = \begin{cases}
+        t / t_{warmup}, & \text{if } t < t_{warmup} \\
+        \alpha, & \text{if } t < t_{max} \\
+        1.0 & \text{otherwise} \end{cases}
+
+    Where :math:`\alpha` represents the learning rate multiplier to maintain while this scheduler is active, and
+    :math:`t_{max}` represents the duration of this scheduler.
+
+    Args:
+        t_warmup (str | Time): Warmup time.
+        alpha (float): Learning rate multiplier to maintain while this scheduler is active. Default = ``1.0``.
+        t_max (str | Time): Duration of this scheduler. Default = ``"1dur"``.
+    """
+
+    def __init__(self, t_warmup: Union[str, Time], alpha: float = 1.0, t_max: Union[str, Time] = '1dur') -> None:
+        self.t_warmup = t_warmup
+        self.alpha = alpha
+        self.t_max = t_max
+        self.scheduler = LinearWithWarmupScheduler(t_warmup=t_warmup, alpha_i=alpha, alpha_f=alpha, t_max=t_max)
+
+    def __call__(self, state: State, ssr: float = 1.0) -> float:
+        return self.scheduler(state, ssr)
+
+
 class LinearWithWarmupScheduler(ComposerScheduler):
     r"""Adjusts the learning rate linearly, with an initial warmup.
 
@@ -613,7 +644,7 @@ class LinearWithWarmupScheduler(ComposerScheduler):
                  t_warmup: Union[str, Time],
                  alpha_i: float = 1.0,
                  alpha_f: float = 0.0,
-                 t_max: Union[str, Time] = "1dur"):
+                 t_max: Union[str, Time] = '1dur'):
         self.t_warmup = t_warmup
         self.alpha_i = alpha_i
         self.alpha_f = alpha_f
@@ -674,7 +705,7 @@ class CosineAnnealingWithWarmupScheduler(ComposerScheduler):
         alpha_f (float): Learning rate multiplier to decay to. Default = ``0.0``.
     """
 
-    def __init__(self, t_warmup: Union[str, Time], t_max: Union[str, Time] = "1dur", alpha_f: float = 0.0):
+    def __init__(self, t_warmup: Union[str, Time], t_max: Union[str, Time] = '1dur', alpha_f: float = 0.0):
         self.t_warmup = t_warmup
         self.t_max = t_max
         self.alpha_f = alpha_f
@@ -718,7 +749,7 @@ class PolynomialWithWarmupScheduler(ComposerScheduler):
     .. math::
        \tau_w = (t - t_{warmup}) / t_{max}
 
-    Where :math:`\kappa` represents the exponent to be used for the proportionality relationship, 
+    Where :math:`\kappa` represents the exponent to be used for the proportionality relationship,
     :math:`t_{warmup}` represents the warmup time, :math:`t_{max}` represents the duration of this scheduler, and
     :math:`\alpha_f` represents the learning rate multiplier to decay to.
 
@@ -737,7 +768,7 @@ class PolynomialWithWarmupScheduler(ComposerScheduler):
     def __init__(self,
                  t_warmup: Union[str, Time],
                  power: float = 2.0,
-                 t_max: Union[str, Time] = "1dur",
+                 t_max: Union[str, Time] = '1dur',
                  alpha_f: float = 0.0):
         self.t_warmup = t_warmup
         self.power = power
