@@ -1,9 +1,11 @@
 # Copyright 2022 MosaicML Composer authors
 # SPDX-License-Identifier: Apache-2.0
 
+"""Action states for the :class:`Profiler` that define whether or not events are being recorded to the trace file."""
+
 from composer.utils.string_enum import StringEnum
 
-__all__ = ["ProfilerAction"]
+__all__ = ['ProfilerAction']
 
 
 class ProfilerAction(StringEnum):
@@ -15,7 +17,7 @@ class ProfilerAction(StringEnum):
         ACTIVE: Record all events to the trace.
         ACTIVE_AND_SAVE: Record all events and save the trace at the end of the batch.
     """
-    SKIP = "skip"
-    WARMUP = "warmup"
-    ACTIVE = "active"
-    ACTIVE_AND_SAVE = "active_and_save"
+    SKIP = 'skip'
+    WARMUP = 'warmup'
+    ACTIVE = 'active'
+    ACTIVE_AND_SAVE = 'active_and_save'
