@@ -9,8 +9,5 @@ Used by :class:`~composer.trainer.trainer.Trainer` in order to train on differen
 from composer.trainer.devices.device import Device as Device
 from composer.trainer.devices.device_cpu import DeviceCPU as DeviceCPU
 from composer.trainer.devices.device_gpu import DeviceGPU as DeviceGPU
-from composer.trainer.devices.device_hparams import CPUDeviceHparams as CPUDeviceHparams
-from composer.trainer.devices.device_hparams import DeviceHparams as DeviceHparams
-from composer.trainer.devices.device_hparams import GPUDeviceHparams as GPUDeviceHparams
 
-__all__ = ["Device", "DeviceCPU", "DeviceGPU"]
+__all__ = ['Device', 'DeviceCPU', 'DeviceGPU']
