@@ -5,25 +5,29 @@
 from composer.utils.batch_helpers import batch_get, batch_set
 from composer.utils.checkpoint import load_checkpoint, save_checkpoint
 from composer.utils.collect_env import configure_excepthook, disable_env_report, enable_env_report, print_env
-from composer.utils.file_helpers import (ensure_folder_has_no_conflicting_files, ensure_folder_is_empty,
-                                         format_name_with_dist, format_name_with_dist_and_time, get_file, is_tar)
+from composer.utils.file_helpers import (create_symlink_file, ensure_folder_has_no_conflicting_files,
+                                         ensure_folder_is_empty, format_name_with_dist, format_name_with_dist_and_time,
+                                         get_file, is_tar)
 from composer.utils.import_helpers import MissingConditionalImportError, import_object
-from composer.utils.iter_helpers import ensure_tuple, iterate_with_pbar, map_collection
-from composer.utils.object_store import ObjectStore, ObjectStoreHparams
+from composer.utils.iter_helpers import IteratorFileStream, ensure_tuple, map_collection
+from composer.utils.object_store import LibcloudObjectStore, ObjectStore, ObjectStoreTransientError
+from composer.utils.retrying import retry
 from composer.utils.string_enum import StringEnum
 
 __all__ = [
     'ensure_tuple',
-    'iterate_with_pbar',
     'map_collection',
+    'IteratorFileStream',
     'get_file',
+    'create_symlink_file',
     'ObjectStore',
-    'ObjectStoreHparams',
-    "MissingConditionalImportError",
-    "import_object",
+    'ObjectStoreTransientError',
+    'LibcloudObjectStore',
+    'MissingConditionalImportError',
+    'import_object',
     'StringEnum',
-    "load_checkpoint",
-    "save_checkpoint",
+    'load_checkpoint',
+    'save_checkpoint',
     'ensure_folder_is_empty',
     'ensure_folder_has_no_conflicting_files',
     'format_name_with_dist',
@@ -35,4 +39,5 @@ __all__ = [
     'disable_env_report',
     'enable_env_report',
     'print_env',
+    'retry',
 ]
