@@ -6,6 +6,7 @@
 from __future__ import annotations
 
 import contextlib
+import fnmatch
 import logging
 import os
 import pathlib
@@ -13,26 +14,26 @@ import shutil
 import tarfile
 import tempfile
 import textwrap
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Tuple, Union
+import warnings
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Union
 
 import torch
 
 from composer.utils import dist, reproducibility
-from composer.utils.file_helpers import (FORMAT_NAME_WITH_DIST_AND_TIME_TABLE, GetFileNotFoundException,
-                                         format_name_with_dist_and_time, get_file, is_tar)
+from composer.utils.file_helpers import (FORMAT_NAME_WITH_DIST_AND_TIME_TABLE, format_name_with_dist_and_time, get_file,
+                                         is_tar)
 from composer.utils.object_store import ObjectStore
 
 if TYPE_CHECKING:
     from composer.core.state import State
     from composer.loggers import LoggerDestination
-    from composer.loggers.logger import Logger
 
 log = logging.getLogger(__name__)
 
-__all__ = ["load_checkpoint", "save_checkpoint"]
+__all__ = ['load_checkpoint', 'save_checkpoint']
 
-_COMPOSER_STATES_FILENAME = "composer_states.pt"
-_DEEPSPEED_TAG = "deepspeed"  # always tag with the same, deterministic name. We'll rename the tarball to the appropriate name.
+_COMPOSER_STATES_FILENAME = 'composer_states.pt'
+_DEEPSPEED_TAG = 'deepspeed'  # always tag with the same, deterministic name. We'll rename the tarball to the appropriate name.
 
 
 def _format_path_with_rank_zero(path: str) -> str:
@@ -57,13 +58,13 @@ def _get_write_mode(name: str) -> str:
     """Get the write mode to use with :func:`tarfile.open`."""
     if name.endswith('.tar'):
         return 'w'
-    if name.endswith(".tar.gz") or name.endswith(".tgz"):
-        return "w:gz"
-    if name.endswith(".tar.bz2"):
-        return "w:bz2"
-    if name.endswith(".tar.lzma"):
-        return "w:xz"
-    raise ValueError(f"{name} does not end with a valid tarfile extension.")
+    if name.endswith('.tar.gz') or name.endswith('.tgz'):
+        return 'w:gz'
+    if name.endswith('.tar.bz2'):
+        return 'w:bz2'
+    if name.endswith('.tar.lzma'):
+        return 'w:xz'
+    raise ValueError(f'{name} does not end with a valid tarfile extension.')
 
 
 def load_checkpoint(
@@ -72,8 +73,8 @@ def load_checkpoint(
     object_store: Optional[Union[ObjectStore, LoggerDestination]] = None,
     load_weights_only: bool = False,
     strict_model_weights: bool = False,
-    chunk_size: int = 1_048_576,
     progress_bar: bool = True,
+    ignore_keys: Optional[Union[List[str], Callable[[Dict], None]]] = None,
 ):
     """Load a checkpoint from a local file, URI, or cloud object store into ``state``.
 
@@ -121,16 +122,36 @@ def load_checkpoint(
             restoring the associated state. (default: ``False``)
         strict_model_weights (bool, optional): Whether or not to force that the checkpointed weights must exactly
             match the model weights. (default: ``False``)
-        chunk_size (int, optional): Chunk size (in bytes) to use when downloading checkpoints.
-            Ignored if the checkpoint is a local file path. (default: ``1_048_576`` bytes (1 MB))
         progress_bar (bool, optional): Whether or not to show a progress bar when downloading checkpoints.
             Ignored if the checkpoint is a local file path. (default: ``True``)
+        ignore_keys (List[str] | (Dict) -> None, optional): A list of paths for the ``state_dict`` of the checkpoint,
+            which, when provided, will be ignored from the state_dict before a checkpoint is loaded. Each path is a list
+            of strings specifying the keys to index into ``state_dict`` joined together with `/` as a seperator (as PyTorch
+            uses `.` in parameter names). If a prefix is provided, all children are also ignored (see Example 2).
+            See :mod:`composer.core.state` for the structure of state_dict.
+
+            Example 1: ``ignore_keys = ["state/model/layer1.weights", "state/model/layer1.bias"]`` would ignore
+            layer 1 weights and bias.
+
+            Example 2: ``ignore_keys = ["state/model/*"]`` would ignore the entire model, which would have the same
+            effect as the previous example if there was only 1 layer.
+
+            Example 3: ``ignore_keys = ["state/model/layer*.weights"]`` would ignore all weights in the model.
+
+            Example 4: ``ignore_keys = ["state/rank_zero_seed", "rng"]`` would reset all randomness when
+            loading the checkpoint.
+
+            If a callable, it should take one argument which is the state_dict. The callable is free to arbitrarily modify
+            the state_dict before it is loaded.
+
+            (default: ``None``)
 
     Returns:
         Optional[List[Dict[str, Any]]]: The RNG state dicts, indexed by global rank, if
             :attr:`load_weights_only` is not None. Otherwise, None.
     """
     # download the checkpoint to the node-local folder
+    log.debug('Loading checkpoint at %s', path)
     tempdir_ctx = tempfile.TemporaryDirectory() if dist.get_local_rank() == 0 else contextlib.nullcontext(None)
     with tempdir_ctx as tempdir:
         try:
@@ -139,7 +160,6 @@ def load_checkpoint(
                 path=path,
                 node_checkpoint_folder=node_checkpoint_folder,
                 object_store=object_store,
-                chunk_size=chunk_size,
                 progress_bar=progress_bar,
             )
             rng_state_dicts = _restore_checkpoint(
@@ -149,13 +169,14 @@ def load_checkpoint(
                 extracted_checkpoint_folder,
                 load_weights_only=load_weights_only,
                 strict_model_weights=strict_model_weights,
+                ignore_keys=ignore_keys,
             )
         finally:
             # Wait for all ranks to finish restoring the checkpoint before releasing the tempdir, since tempdir can
             # be a shared resource between nodes.
             dist.barrier()
 
-    log.info("%s loaded from %s", "Model weights" if load_weights_only else "Trainer checkpoint", path)
+    log.info('%s loaded from %s', 'Model weights' if load_weights_only else 'Trainer checkpoint', path)
     return rng_state_dicts
 
 
@@ -164,7 +185,7 @@ def _get_node_checkpoint_download_folder(path: Optional[str]) -> str:
     local_rank_zero = dist.get_local_world_size() * dist.get_node_rank()
     paths = dist.all_gather_object(path)
     local_rank_zero_path = paths[local_rank_zero]
-    assert local_rank_zero_path is not None, "local rank zero provides the path"
+    assert local_rank_zero_path is not None, 'local rank zero provides the path'
     return local_rank_zero_path
 
 
@@ -172,7 +193,6 @@ def _download_checkpoint(
     path: str,
     node_checkpoint_folder: str,
     object_store: Optional[Union[ObjectStore, LoggerDestination]],
-    chunk_size: int,
     progress_bar: bool,
 ) -> Tuple[str, Optional[str], bool]:
     """Download the checkpoint stored at ``path``, potentially in ``object_store``, to ``node_checkpoint_folder``.
@@ -186,12 +206,13 @@ def _download_checkpoint(
     *   The ``extracted_rank_n`` is a boolean flag indicating whether a tarball was extracted on global
         rank greater than 0.
     """
-    rank_zero_checkpoint_filepath = os.path.join(node_checkpoint_folder, "rank0_checkpoint")
-    rank_n_checkpoint_filepath = os.path.join(node_checkpoint_folder, f"rank{dist.get_global_rank()}_checkpoint")
+    log.debug('Downloading checkpoint to folder %s', node_checkpoint_folder)
+    rank_zero_checkpoint_filepath = os.path.join(node_checkpoint_folder, 'rank0_checkpoint')
+    rank_n_checkpoint_filepath = os.path.join(node_checkpoint_folder, f'rank{dist.get_global_rank()}_checkpoint')
     extracted_checkpoint_folder = None
     extracted_rank_n = False
     if is_tar(path):
-        extracted_checkpoint_folder = os.path.join(node_checkpoint_folder, "checkpoint")
+        extracted_checkpoint_folder = os.path.join(node_checkpoint_folder, 'checkpoint')
         composer_states_filepath = os.path.join(extracted_checkpoint_folder, _COMPOSER_STATES_FILENAME)
     else:
         # it's not an archive; it's just the composer state dict
@@ -206,7 +227,6 @@ def _download_checkpoint(
             get_file(destination=rank_zero_checkpoint_filepath,
                      path=path,
                      object_store=object_store,
-                     chunk_size=chunk_size,
                      progress_bar=progress_bar)
             if extracted_checkpoint_folder is not None:
                 try:
@@ -216,20 +236,19 @@ def _download_checkpoint(
                     # Not re-raising the file-not-found error as that is irrelevant;
                     # the underlying issue is that the checkpoint file does not exist on the disk
                     # or could not be downloaded
-                    raise RuntimeError(f"Checkpoint {path} does not exist")
+                    raise RuntimeError(f'Checkpoint {path} does not exist')
 
         if rank_zero_checkpoint_filepath != rank_n_checkpoint_filepath:
             # every RANK needs ITS OWN checkpoint.
             # But, the  global rank zero is a special case -- these files are the same!
-            assert dist.get_global_rank() != 0, "invariant violation"
+            assert dist.get_global_rank() != 0, 'invariant violation'
 
             try:
                 get_file(destination=rank_n_checkpoint_filepath,
                          path=_format_path_with_current_rank(path),
                          object_store=object_store,
-                         chunk_size=chunk_size,
                          progress_bar=progress_bar)
-            except GetFileNotFoundException:
+            except FileNotFoundError:
                 # Allowing not-found errors to be ignored as sometimes there won't be rank-local checkpoints
                 # (e.g. when not using deepspeed)
                 pass
@@ -256,6 +275,74 @@ def _download_checkpoint(
     return composer_states_filepath, extracted_checkpoint_folder, extracted_rank_n
 
 
+def _flatten_keys(obj: Any, paths: List[str], existing_path: str):
+    """Recursively flatten the keys of a dictionary or list into a set of paths."""
+    # Store path when we reach end, which is either non-Dict or empty Dict
+    if isinstance(obj, list) and len(obj) > 0:
+        for i, elm in enumerate(obj):
+            _flatten_keys(elm, paths, f'{existing_path}/{i}')
+    elif isinstance(obj, dict) and len(obj) > 0:
+        for k, v in obj.items():
+            _flatten_keys(v, paths, f'{existing_path}/{k}')
+    # Remove leading /
+    paths.append(existing_path.lstrip('/'))
+
+
+def _remove_paths(obj: Union[list, Dict[str, Any]], exclude_paths: List[List[str]]):
+    # First determine the keys which will be recursed on and which will be removed entirely
+    # Group the `exclude_paths` by the key
+    keys_to_recurse = {}
+    keys_to_remove = []
+    for exclude_path_parts in exclude_paths:
+        key = exclude_path_parts[0]
+        if isinstance(obj, list):
+            key = int(key)
+        if len(exclude_path_parts) == 1:
+            keys_to_remove.append(key)
+        else:
+            if key not in keys_to_recurse:
+                keys_to_recurse[key] = []
+            keys_to_recurse[key].append(exclude_path_parts[1:])
+
+    # Recurse first, so in the case of a list, the indexing is consistent
+    for key, paths_to_recurse in keys_to_recurse.items():
+        _remove_paths(obj[key], paths_to_recurse)
+
+    # Sort the keys in reverse order, so in the case of a list, the indexing is consistent
+    keys_to_remove.sort(reverse=True)
+
+    # Remove the keys
+    for key in keys_to_remove:
+        del obj[key]
+
+
+def glob_filter(exclude_globs: List[str]) -> Callable[[Dict], None]:
+    """Provides a function which deletes all subparts of a dictionary based on a list of paths."""
+
+    def filter_func(state_dict: Dict) -> None:
+        # Flatten dictionary into paths
+        paths = []
+        _flatten_keys(state_dict, paths, '/')
+
+        filtered_paths = []
+        for exclude_glob in exclude_globs:
+            filtered_paths_from_glob = fnmatch.filter(paths, exclude_glob)
+            if len(filtered_paths_from_glob) == 0:
+                warnings.warn(
+                    f'No parts from loaded checkpoint state_dict were ignored by load_ignore_key {exclude_glob}')
+            filtered_paths.extend(filtered_paths_from_glob)
+        filtered_paths = list(set(filtered_paths))
+        filtered_paths_str = ', '.join(filtered_paths)
+        if filtered_paths:
+            log.info(f'Ignoring the following paths from the loaded checkpoint state_dict: {filtered_paths_str}')
+
+        # Loop through all paths to exclude
+        paths_to_remove = [path.split('/') for path in filtered_paths]
+        _remove_paths(state_dict, paths_to_remove)
+
+    return filter_func
+
+
 def _restore_checkpoint(
     state: State,
     composer_states_filepath: str,
@@ -263,19 +350,26 @@ def _restore_checkpoint(
     extracted_checkpoint_folder: Optional[str],
     load_weights_only: bool,
     strict_model_weights: bool,
+    ignore_keys: Optional[Union[List[str], Callable[[Dict], None]]],
 ) -> Optional[List[Dict[str, Any]]]:
     """Restore a checkpoint into ``state`` and returns the rng state dicts (if ``load_weights_only`` is False)."""
     # Now, all ranks load the checkpoint that local rank zero downloaded
     state_dict = torch.load(composer_states_filepath, map_location='cpu')
+    if ignore_keys:
+        # Filter provided list of key paths
+        if not callable(ignore_keys):
+            ignore_keys = glob_filter(ignore_keys)
+        # Call function to modify state_dict
+        ignore_keys(state_dict)
     log.debug(f"Loaded checkpoint with keys {state_dict.keys()} and state keys {state_dict['state'].keys()}")
 
     if state.is_model_deepspeed:
         if extracted_checkpoint_folder is None:
-            raise RuntimeError("Deepspeed checkpoints require a tarball, not a weights file.")
+            raise RuntimeError('Deepspeed checkpoints require a tarball, not a weights file.')
 
         global_rank = dist.get_global_rank()
         if global_rank > 0 and not extracted_rank_n:
-            raise RuntimeError(f"Deepspeed checkpoint missing for rank {global_rank}")
+            raise RuntimeError(f'Deepspeed checkpoint missing for rank {global_rank}')
 
         load_path, _ = state.deepspeed_model.load_checkpoint(
             extracted_checkpoint_folder,
@@ -284,7 +378,7 @@ def _restore_checkpoint(
             load_module_strict=strict_model_weights,
         )
         if load_path is None:
-            raise RuntimeError(f"Failed to load DeepSpeed checkpoint")
+            raise RuntimeError(f'Failed to load DeepSpeed checkpoint')
     elif load_weights_only:
         state.load_model_state(state_dict['state'], strict=strict_model_weights)
 
@@ -293,22 +387,24 @@ def _restore_checkpoint(
         return state_dict['rng']
 
 
-def save_checkpoint(state: State,
-                    logger: Logger,
-                    filename: str = "ep{epoch}-ba{batch}-rank{rank}",
-                    *,
-                    weights_only: bool = False) -> List[pathlib.Path]:
+def save_checkpoint(
+    state: State,
+    filename: str = 'ep{epoch}-ba{batch}-rank{rank}',
+    *,
+    weights_only: bool = False,
+) -> List[pathlib.Path]:  # noqa: D103
+    log.debug('Saving checkpoint to %s', filename)
     state_dict = {
         'state': state.state_dict(),
         'rng': reproducibility.get_rng_state(),
     }
     if weights_only and not state.is_model_deepspeed:
-        state_dict['state'] = {"model": state_dict['state']['model']}
+        state_dict['state'] = {'model': state_dict['state']['model']}
 
-    checkpoint_filepath = format_name_with_dist_and_time(filename, logger.run_name, state.timestamp)
+    checkpoint_filepath = format_name_with_dist_and_time(filename, state.run_name, state.timestamp)
     if state.is_model_deepspeed and not is_tar(checkpoint_filepath):
         # Deepspeed requires tarballs; appending `.tar`
-        checkpoint_filepath += ".tar"
+        checkpoint_filepath += '.tar'
 
     with tempfile.TemporaryDirectory() as tmpdir:
         composer_states_filepath = os.path.join(tmpdir, _COMPOSER_STATES_FILENAME)
@@ -332,7 +428,7 @@ def save_checkpoint(state: State,
             write_mode = _get_write_mode(checkpoint_filepath)
             with tarfile.open(checkpoint_filepath, write_mode) as tarball:
                 # add files flat to the tarball with the specified compression
-                tarball.add(tmpdir, arcname="")
+                tarball.add(tmpdir, arcname='')
         elif dist.get_global_rank() == 0:
             # if not an archive, then only saving the states
             # only rank zero saves the state dict
