@@ -8,35 +8,32 @@ from __future__ import annotations
 import os
 import pathlib
 import re
-from typing import TYPE_CHECKING, Iterator, Optional, Union
+import tempfile
+import uuid
+from typing import TYPE_CHECKING, Optional, Union
 
 import requests
 import tqdm
 
 from composer.core.time import Time, Timestamp
 from composer.utils import dist
-from composer.utils.iter_helpers import iterate_with_pbar
+from composer.utils.iter_helpers import iterate_with_callback
 from composer.utils.object_store import ObjectStore
 
 if TYPE_CHECKING:
     from composer.loggers import LoggerDestination
 
 __all__ = [
-    'GetFileNotFoundException',
     'get_file',
     'ensure_folder_is_empty',
     'ensure_folder_has_no_conflicting_files',
     'format_name_with_dist',
     'format_name_with_dist_and_time',
     'is_tar',
+    'create_symlink_file',
 ]
 
 
-class GetFileNotFoundException(RuntimeError):
-    """Exception if :meth:`get_file` failed due to a not found error."""
-    pass
-
-
 def is_tar(name: Union[str, pathlib.Path]) -> bool:
     """Returns whether ``name`` has a tar-like extension.
 
@@ -46,7 +43,7 @@ def is_tar(name: Union[str, pathlib.Path]) -> bool:
     Returns:
         bool: Whether ``name`` is a tarball.
     """
-    return any(str(name).endswith(x) for x in (".tar", ".tgz", ".tar.gz", ".tar.bz2", ".tar.lzma"))
+    return any(str(name).endswith(x) for x in ('.tar', '.tgz', '.tar.gz', '.tar.bz2', '.tar.lzma'))
 
 
 def ensure_folder_is_empty(folder_name: Union[str, pathlib.Path]):
@@ -64,14 +61,16 @@ def ensure_folder_is_empty(folder_name: Union[str, pathlib.Path]):
         # Filter out hidden folders
         dirs[:] = (x for x in dirs if not x.startswith('.'))
         for file in files:
-            if not file.startswith("."):
-                raise FileExistsError(f"{folder_name} is not empty; {os.path.join(root, file)} exists.")
+            if not file.startswith('.'):
+                raise FileExistsError(f'{folder_name} is not empty; {os.path.join(root, file)} exists.')
 
 
 def ensure_folder_has_no_conflicting_files(folder_name: Union[str, pathlib.Path], filename: str, timestamp: Timestamp):
-    """Ensure that the given folder does not have any files conflicting with the ``filename`` format string. If any
-    filename is formatted with a timestamp where the epoch, batch, sample, or token counts are after ``timestamp``, a
-    ``FileExistsError`` will be raised. ``filename`` and occurs later than ``timestamp``, raise a ``FileExistsError``.
+    """Ensure that the given folder does not have any files conflicting with the ``filename`` format string.
+
+    If any filename is formatted with a timestamp where the epoch, batch, sample, or token counts are after
+    ``timestamp``, a ``FileExistsError`` will be raised.
+    If ``filename`` and occurs later than ``timestamp``, raise a ``FileExistsError``.
 
     Args:
         folder_name (str | pathlib.Path): The folder to inspect.
@@ -82,13 +81,13 @@ def ensure_folder_has_no_conflicting_files(folder_name: Union[str, pathlib.Path]
         FileExistsError: If ``folder_name`` contains any files matching the ``filename`` template before ``timestamp``.
     """
     # Prepare regex pattern by replacing f-string formatting with regex.
-    pattern = f"^{filename}$"
+    pattern = f'^{filename}$'
     # Format time vars for capture
-    time_names = ["epoch", "batch", "sample", "token", "batch_in_epoch", "sample_in_epoch", "token_in_epoch"]
-    captured_names = {time_name: f"{{{time_name}}}" in filename for time_name in time_names}
+    time_names = ['epoch', 'batch', 'sample', 'token', 'batch_in_epoch', 'sample_in_epoch', 'token_in_epoch']
+    captured_names = {time_name: f'{{{time_name}}}' in filename for time_name in time_names}
     for time_name, is_captured in captured_names.items():
         if is_captured:
-            pattern = pattern.replace(f"{{{time_name}}}", f"(?P<{time_name}>\\d+)")
+            pattern = pattern.replace(f'{{{time_name}}}', f'(?P<{time_name}>\\d+)')
     # Format rank information
     pattern = pattern.format(rank=dist.get_global_rank(),
                              local_rank=dist.get_local_rank(),
@@ -104,28 +103,28 @@ def ensure_folder_has_no_conflicting_files(folder_name: Union[str, pathlib.Path]
         if match is not None:
             valid_match = True
             # Check each base unit of time and flag later checkpoints
-            if captured_names["token"] and Time.from_token(int(match.group("token"))) > timestamp.token:
+            if captured_names['token'] and Time.from_token(int(match.group('token'))) > timestamp.token:
                 valid_match = False
-            elif captured_names["sample"] and Time.from_sample(int(match.group("sample"))) > timestamp.sample:
+            elif captured_names['sample'] and Time.from_sample(int(match.group('sample'))) > timestamp.sample:
                 valid_match = False
-            elif captured_names["batch"] and Time.from_batch(int(match.group("batch"))) > timestamp.batch:
+            elif captured_names['batch'] and Time.from_batch(int(match.group('batch'))) > timestamp.batch:
                 valid_match = False
-            elif captured_names["epoch"] and Time.from_epoch(int(match.group("epoch"))) > timestamp.epoch:
+            elif captured_names['epoch'] and Time.from_epoch(int(match.group('epoch'))) > timestamp.epoch:
                 valid_match = False
             # If epoch count is same, check batch_in_epoch, sample_in_epoch, token_in_epoch
-            elif captured_names["epoch"] and Time.from_epoch(int(match.group("epoch"))) == timestamp.epoch:
-                if captured_names["token_in_epoch"] and Time.from_token(int(
-                        match.group("token_in_epoch"))) > timestamp.token_in_epoch:
+            elif captured_names['epoch'] and Time.from_epoch(int(match.group('epoch'))) == timestamp.epoch:
+                if captured_names['token_in_epoch'] and Time.from_token(int(
+                        match.group('token_in_epoch'))) > timestamp.token_in_epoch:
                     valid_match = False
-                elif captured_names["sample_in_epoch"] and Time.from_sample(int(
-                        match.group("sample_in_epoch"))) > timestamp.sample_in_epoch:
+                elif captured_names['sample_in_epoch'] and Time.from_sample(int(
+                        match.group('sample_in_epoch'))) > timestamp.sample_in_epoch:
                     valid_match = False
-                elif captured_names["batch_in_epoch"] and Time.from_batch(int(
-                        match.group("batch_in_epoch"))) > timestamp.batch_in_epoch:
+                elif captured_names['batch_in_epoch'] and Time.from_batch(int(
+                        match.group('batch_in_epoch'))) > timestamp.batch_in_epoch:
                     valid_match = False
             if not valid_match:
                 raise FileExistsError(
-                    f"{os.path.join(folder_name, file)} exists and conflicts in namespace with a future checkpoint of the current run."
+                    f'{os.path.join(folder_name, file)} exists and conflicts in namespace with a future checkpoint of the current run.'
                 )
 
 
@@ -154,7 +153,7 @@ FORMAT_NAME_WITH_DIST_TABLE = """
 """
 
 
-def format_name_with_dist(format_str: str, run_name: str, **extra_format_kwargs: object):
+def format_name_with_dist(format_str: str, run_name: str, **extra_format_kwargs: object):  # noqa: D103
     formatted_str = format_str.format(
         run_name=run_name,
         rank=dist.get_global_rank(),
@@ -246,7 +245,12 @@ FORMAT_NAME_WITH_DIST_AND_TIME_TABLE = """
 """
 
 
-def format_name_with_dist_and_time(format_str: str, run_name: str, timestamp: Timestamp, **extra_format_kwargs: object):
+def format_name_with_dist_and_time(
+    format_str: str,
+    run_name: str,
+    timestamp: Timestamp,
+    **extra_format_kwargs: object,
+):  # noqa: D103
     formatted_str = format_str.format(
         run_name=run_name,
         rank=dist.get_global_rank(),
@@ -300,13 +304,13 @@ def get_file(
     path: str,
     destination: str,
     object_store: Optional[Union[ObjectStore, LoggerDestination]] = None,
-    chunk_size: int = 2**20,
+    overwrite: bool = False,
     progress_bar: bool = True,
 ):
     """Get a file from a local folder, URL, or object store.
 
     Args:
-        path (str): The path to the file to retreive.
+        path (str): The path to the file to retrieve.
 
             *   If ``object_store`` is specified, then the ``path`` should be the object name for the file to get.
                 Do not include the the cloud provider or bucket name.
@@ -324,86 +328,174 @@ def get_file(
         object_store (ObjectStore, optional): An :class:`~.ObjectStore`, if ``path`` is located inside
             an object store (i.e. AWS S3 or Google Cloud Storage). (default: ``None``)
 
-            This :class:`~.ObjectStore` instance will be used to retreive the file. The ``path`` parameter
+            This :class:`~.ObjectStore` instance will be used to retrieve the file. The ``path`` parameter
             should be set to the object name within the object store.
 
             Set this parameter to ``None`` (the default) if ``path`` is a URL or a local file.
 
-        chunk_size (int, optional): Chunk size (in bytes). Ignored if ``path`` is a local file. (default: 1MB)
+        overwrite (bool): Whether to overwrite an existing file at ``destination``. (default: ``False``)
 
         progress_bar (bool, optional): Whether to show a progress bar. Ignored if ``path`` is a local file.
             (default: ``True``)
 
     Raises:
-        GetFileNotFoundException: If the ``path`` does not exist, a ``GetFileNotFoundException`` exception will
-            be raised.
+        FileNotFoundError: If the ``path`` does not exist.
     """
+    if path.endswith('.symlink'):
+        with tempfile.TemporaryDirectory() as tmpdir:
+            symlink_file_name = os.path.join(tmpdir, 'file.symlink')
+            # Retrieve the symlink
+            _get_file(
+                path=path,
+                destination=symlink_file_name,
+                object_store=object_store,
+                overwrite=False,
+                progress_bar=progress_bar,
+            )
+            # Read object name in the symlink
+            with open(symlink_file_name, 'r') as f:
+                real_path = f.read()
+
+        # Recurse
+        return get_file(
+            path=real_path,
+            destination=destination,
+            object_store=object_store,
+            overwrite=overwrite,
+            progress_bar=progress_bar,
+        )
+
+    try:
+        _get_file(
+            path=path,
+            destination=destination,
+            object_store=object_store,
+            overwrite=overwrite,
+            progress_bar=progress_bar,
+        )
+    except FileNotFoundError as e:
+        new_path = path + '.symlink'
+        try:
+            # Follow the symlink
+            return get_file(
+                path=new_path,
+                destination=destination,
+                object_store=object_store,
+                overwrite=overwrite,
+                progress_bar=progress_bar,
+            )
+        except FileNotFoundError as ee:
+            # Raise the original not found error first, which contains the path to the user-specified file
+            raise e from ee
+
+
+def _get_file(
+    path: str,
+    destination: str,
+    object_store: Optional[Union[ObjectStore, LoggerDestination]],
+    overwrite: bool,
+    progress_bar: bool,
+):
+    # Underlying _get_file logic that does not deal with symlinks
     if object_store is not None:
         if isinstance(object_store, ObjectStore):
-            # Type ObjectStore
-            try:
-                total_size_in_bytes = object_store.get_object_size(path)
-            except Exception as e:
-                if "ObjectDoesNotExistError" in str(e):
-                    raise GetFileNotFoundException(
-                        f"Object name {path} not found in object store {object_store}") from e
-                raise
-            _write_to_file_with_pbar(
-                destination=destination,
-                total_size=total_size_in_bytes,
-                iterator=object_store.download_object_as_stream(path, chunk_size=chunk_size),
-                progress_bar=progress_bar,
-                description=f"Downloading {path}",
+            total_size_in_bytes = object_store.get_object_size(path)
+            object_store.download_object(
+                object_name=path,
+                filename=destination,
+                callback=_get_callback(f'Downloading {path}') if progress_bar else None,
+                overwrite=overwrite,
             )
         else:
             # Type LoggerDestination
-            object_store.get_file_artifact(artifact_name=path,
-                                           destination=destination,
-                                           chunk_size=chunk_size,
-                                           progress_bar=progress_bar)
+            object_store.get_file_artifact(
+                artifact_name=path,
+                destination=destination,
+                progress_bar=progress_bar,
+                overwrite=overwrite,
+            )
         return
 
-    if path.lower().startswith("http://") or path.lower().startswith("https://"):
+    if path.lower().startswith('http://') or path.lower().startswith('https://'):
         # it's a url
         with requests.get(path, stream=True) as r:
             try:
                 r.raise_for_status()
             except requests.exceptions.HTTPError as e:
                 if r.status_code == 404:
-                    raise GetFileNotFoundException(f"URL {path} not found") from e
+                    raise FileNotFoundError(f'URL {path} not found') from e
                 raise e
             total_size_in_bytes = r.headers.get('content-length')
             if total_size_in_bytes is not None:
                 total_size_in_bytes = int(total_size_in_bytes)
-            _write_to_file_with_pbar(
-                destination,
-                total_size=total_size_in_bytes,
-                iterator=r.iter_content(chunk_size),
-                progress_bar=progress_bar,
-                description=f"Downloading {path}",
-            )
+            else:
+                total_size_in_bytes = 0
+
+            tmp_path = destination + f'.{uuid.uuid4()}.tmp'
+            try:
+                with open(tmp_path, 'wb') as f:
+                    for data in iterate_with_callback(
+                            r.iter_content(2**20),
+                            total_size_in_bytes,
+                            callback=_get_callback(f'Downloading {path}') if progress_bar else None,
+                    ):
+                        f.write(data)
+            except:
+                # The download failed for some reason. Make a best-effort attempt to remove the temporary file.
+                try:
+                    os.remove(tmp_path)
+                except OSError:
+                    pass
+                raise
+            else:
+                os.rename(tmp_path, destination)
         return
 
     # It's a local filepath
     if not os.path.exists(path):
-        raise GetFileNotFoundException(f"Local path {path} does not exist")
+        raise FileNotFoundError(f'Local path {path} does not exist')
     os.symlink(os.path.abspath(path), destination)
 
 
-def _write_to_file_with_pbar(
-    destination: str,
-    total_size: Optional[int],
-    iterator: Iterator[bytes],
-    progress_bar: bool,
-    description: str,
+def _get_callback(description: str):
+    if len(description) > 60:
+        description = description[:42] + '...' + description[-15:]
+    pbar = None
+
+    def callback(num_bytes: int, total_size: int):
+        nonlocal pbar
+        if num_bytes == 0 or pbar is None:
+            pbar = tqdm.tqdm(desc=description, total=total_size, unit='iB', unit_scale=True)
+        n = num_bytes - pbar.n
+        pbar.update(n)
+        if num_bytes == total_size:
+            pbar.close()
+
+    return callback
+
+
+def create_symlink_file(
+    existing_path: str,
+    destination_filename: Union[str, pathlib.Path],
 ):
-    """Write the contents of ``iterator`` to ``destination`` while showing a progress bar."""
-    if progress_bar:
-        if len(description) > 60:
-            description = description[:42] + "..." + description[-15:]
-        pbar = tqdm.tqdm(desc=description, total=total_size, unit='iB', unit_scale=True)
-    else:
-        pbar = None
-    with open(destination, "wb") as fp:
-        for chunk in iterate_with_pbar(iterator, pbar):
-            fp.write(chunk)
+    """Create a symlink file, which can be followed by :func:`get_file`.
+
+    Unlike unix symlinks, symlink files can be created by this function are normal text files and can be
+    uploaded to object stores via :meth:`.ObjectStore.upload_object` or loggers via :meth:`.Logger.file_artifact`
+    that otherwise would not support unix-style symlinks.
+
+    Args:
+        existing_path (str): The name of existing object that the symlink file should point to.
+        destination_filename (str | pathlib.Path): The filename to which to write the symlink.
+            It must end in ``'.symlink'``.
+    """
+    # Loggers might not natively support symlinks, so we emulate symlinks via text files ending with `.symlink`
+    # This text file contains the name of the object it is pointing to.
+    # Only symlink if we're logging artifact to begin with
+    # Write artifact name into file to emulate symlink
+    # Add .symlink extension so we can identify as emulated symlink when downloading
+    destination_filename = str(destination_filename)
+    if not destination_filename.endswith('.symlink'):
+        raise ValueError('The symlink filename must end with .symlink.')
+    with open(destination_filename, 'x') as f:
+        f.write(existing_path)
